---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:legge:1978-12-23;833
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19781228&codiceRedaz=078U0833&dataVigenza=20251104
dataGU: 19781228
codiceRedaz: 078U0833
dataVigenza: 20251104
---

# Istituzione del servizio sanitario nazionale.

La Camera dei deputati ed il Senato della Repubblica hanno approvato;

IL PRESIDENTE DELLA REPUBBLICA

PROMULGA la seguente legge:

## IL SERVIZIO SANITARIO NAZIONALE CAPO I PRINCIPI ED OBIETTIVI

### Art. 1. - (I principi)

La Repubblica tutela la salute come fondamentale diritto dell'individuo e interesse della collettivita' mediante il servizio sanitario nazionale. La tutela della salute fisica e psichica deve avvenire nel rispetto della dignita' e della liberta' della persona umana. Il servizio sanitario nazionale e' costituito dal complesso delle funzioni, delle strutture, dei servizi e delle attivita' destinati alla promozione, al mantenimento ed al recupero della salute fisica e psichica di tutta la popolazione senza distinzione di condizioni individuali o sociali e secondo modalita' che assicurino l'eguaglianza dei cittadini nei confronti del servizio. L'attuazione del servizio sanitario nazionale compete allo Stato, alle regioni e agli enti locali territoriali, garantendo la partecipazione dei cittadini. Nel servizio sanitario nazionale e' assicurato il collegamento ed il coordinamento con le attivita' e con gli interventi di tutti gli altri organi, centri, istituzioni e servizi, che svolgono nel settore sociale attivita' comunque incidenti sullo stato di salute degli individui e della collettivita'. Le associazioni di volontariato possono concorrere ai fini istituzionali del servizio sanitario nazionale nei modi e nelle forme stabiliti dalla presente legge.

### Art. 2. - (Gli obiettivi)

Il conseguimento delle finalita' di cui al precedente articolo e' assicurato mediante: 1) la formazione di una moderna coscienza sanitaria sulla base di un'adeguata educazione sanitaria del cittadino e delle comunita'; 2) la prevenzione delle malattie e degli infortuni in ogni ambito di vita e di lavoro; 3) la diagnosi e la cura degli eventi morbosi quali che ne siano le cause, la fenomenologia e la durata; 4) la riabilitazione degli stati di invalidita' e di inabilita' somatica e psichica; 5) la promozione e la salvaguardia della salubrita' e dell'igiene dell'ambiente naturale di vita e di lavoro; 6) l'igiene degli alimenti, delle bevande, dei prodotti e avanzi di origine animale per le implicazioni che attengono alla salute dell'uomo, nonche' la prevenzione e la difesa sanitaria degli allevamenti animali ed il controllo della loro alimentazione integrata e medicata; 7) una disciplina della sperimentazione, produzione, immissione in commercio e distribuzione dei farmaci e dell'informazione scientifica sugli stessi diretta ad assicurare l'efficacia terapeutica, la non nocivita' e la economicita' del prodotto; 8) la formazione professionale e permanente nonche' l'aggiornamento scientifico culturale del personale del servizio sanitario nazionale. Il servizio sanitario nazionale nell'ambito delle sue competenze persegue: a) il superamento degli squilibri territoriali nelle condizioni socio-sanitarie del paese; b) la sicurezza del lavoro, con la partecipazione dei lavoratori e delle loro organizzazioni, per prevenire ed eliminare condizioni pregiudizievoli alla salute e per garantire nelle fabbriche e negli altri luoghi di lavoro gli strumenti ed i servizi necessari; c) le scelte responsabili e consapevoli di procreazione e la tutela della maternita' e dell'infanzia, per assicurare la riduzione dei fattori di rischio connessi con la gravidanza e con il parto, le migliori condizioni di salute per la madre e la riduzione del tasso di patologia e di mortalita' perinatale ed infantile; d) la promozione della salute nell'eta' evolutiva, garantendo l'attuazione dei servizi medico-scolastici negli istituti di istruzione pubblica e privata di ogni ordine e grado, a partire dalla scuola materna, e favorendo con ogni mezzo l'integrazione dei soggetti handicappati; e) la tutela sanitaria delle attivita' sportive; f) la tutela della salute degli anziani, anche al fine di prevenire e di rimuovere le condizioni che possono concorrere alla loro emarginazione; g) la tutela della salute mentale, privilegiando il momento preventivo e inserendo i servizi psichiatrici nei servizi sanitari generali in modo da eliminare ogni forma di discriminazione e di segregazione, pur nella specificita' delle misure terapeutiche, e da favorire il recupero ed il reinserimento sociale dei disturbati psichici; h) ((LETTERA ABROGATA DAL D.P.R. 5 GIUGNO 1993, N. 177 A SEGUITO DI REFERENDUM POPOLARE)).

## COMPETENZE E STRUTTURE

### Art. 3. - (Programmazione di obiettivi e di prestazioni sanitarie)

Lo Stato, nell'ambito della programmazione economica nazionale, determina, con il concorso delle regioni, gli obiettivi della programmazione sanitaria nazionale. La legge dello Stato, in sede di approvazione del piano sanitario nazionale di cui all'articolo 53, fissa i livelli delle prestazioni sanitarie che devono essere, comunque, garantite a tutti i cittadini.

### Art. 4. - (Uniformita' delle condizioni di salute sul territorio nazionale)

Con legge dello Stato sono dettate norme dirette ad assicurare condizioni e garanzie di salute uniformi per tutto il territorio nazionale e stabilite le relative sanzioni penali, particolarmente in materia di: 1) inquinamento dell'atmosfera, delle acque e del suolo; 2) igiene e sicurezza in ambienti di vita e di lavoro; 3) omologazione, per fini prevenzionali, di macchine, di impianti, di attrezzature e di mezzi personali di protezione; 4) tutela igienica degli alimenti e delle bevande; 5) ricerca e sperimentazione clinica e sperimentazione sugli animali; 6) raccolta, frazionamento, conservazione e distribuzione del sangue umano. Con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro della sanita', sentito il Consiglio sanitario nazionale, sono fissati e periodicamente sottoposti a revisione i limiti massimi di accettabilita' delle concentrazioni e i limiti massimi di esposizione relativi ad inquinanti di natura chimica, fisica e biologica e delle emissioni sonore negli ambienti di lavoro, abitativi e nell'ambiente esterno.

### Art. 5. - (Indirizzo e coordinamento delle attivita' amministrative regionali)

La funzione di indirizzo e coordinamento delle attivita' amministrative delle regioni in materia sanitaria, attinente ad esigenze di carattere unitario, anche con riferimento agli obiettivi della programmazione economica nazionale, ad esigenze di rigore e di efficacia della spesa sanitaria nonche' agli impegni derivanti dagli obblighi internazionali e comunitari, spetta allo Stato e viene esercitata, fuori dei casi in cui si provveda con legge o con atto avente forza di legge, mediante deliberazioni del Consiglio dei ministri, su proposta del Presidente del Consiglio, d'intesa con il Ministro della sanita', sentito il Consiglio sanitario nazionale. Fuori dei casi in cui si provveda con legge o con atto avente forza di legge, l'esercizio della funzione di cui al precedente comma puo' essere delegato di volta in volta dal Consiglio dei ministri al Comitato interministeriale per la programmazione economica (CIPE), per la determinazione dei criteri operativi nelle materie di sua competenza, oppure al Presidente del Consiglio dei ministri, d'intesa con il Ministro della sanita' quando si tratti di affari particolari. Il Ministro della sanita' esercita le competenze attribuitegli dalla presente legge ed emana le direttive concernenti le attivita' delegate alle regioni. In caso di persistente inattivita' degli organi regionali nell'esercizio delle funzioni delegate, qualora l'inattivita' relativa alle materie delegate riguardi adempimenti da svolgersi entro termini perentori previsti dalla legge o risultanti dalla natura degli interventi, il Consiglio dei ministri, su proposta del Ministro della sanita', dispone il compimento degli atti relativi in sostituzione dell'amministrazione regionale. Il Ministro della sanita' e le amministrazioni regionali sono tenuti a fornirsi reciprocamente ed a richiesta ogni notizia utile allo svolgimento delle proprie funzioni.

### Art. 6. - (Competenze dello Stato)

Sono di competenza dello Stato le funzioni amministrative concernenti: a) i rapporti internazionali e la profilassi internazionale, marittima, aerea e di frontiera, anche in materia veterinaria; l'assistenza sanitaria ai cittadini italiani all'estero e l'assistenza in Italia agli stranieri ed agli apolidi, nei limiti ed alle condizioni previste da impegni internazionali, avvalendosi dei presidi sanitari esistenti; b) la profilassi delle malattie infettive e diffusive, per le quali siano imposte la vaccinazione obbligatoria o misure quarantenarie, nonche' gli interventi contro le epidemie e le epizoozie; c) la produzione, la registrazione, la ricerca, la sperimentazione, il commercio e l'informazione concernenti i prodotti chimici usati in medicina, i preparati farmaceutici, i preparati galenici, le specialita' medicinali, i vaccini, gli immunomodulatori cellulari e virali, i sieri, le anatossine e i prodotti assimilati, gli emoderivati, i presidi sanitari e medico-chirurgici ed i prodotti assimilati anche per uso veterinario; d) la coltivazione, la produzione, la fabbricazione, l'impiego, il commercio all'ingrosso, l'esportazione, l'importazione, il transito, l'acquisto, la vendita e la detenzione di sostanze stupefacenti o psicotrope, salvo che per le attribuzioni gia' conferite alle regioni dalla legge 22 dicembre 1975, n. 685; e) la produzione, la registrazione e il commercio dei prodotti dietetici, degli alimenti per la prima infanzia e la cosmesi; f) l'elencazione e la determinazione delle modalita' di impiego degli additivi e dei coloranti permessi nella lavorazione degli alimenti e delle bevande e nella produzione degli oggetti d'uso personale e domestico; la determinazione delle caratteristiche igienico-sanitarie dei materiali e dei recipienti destinati a contenere e conservare sostanze alimentari e bevande, nonche' degli oggetti destinati comunque a venire a contatto con sostanze alimentari; g) gli standards dei prodotti industriali; h) la determinazione di indici di qualita' e di salubrita' degli alimenti e delle bevande alimentari; i) la produzione, la registrazione, il commercio e l'impiego delle sostanze chimiche e delle forme di energia capaci di alterare l'equilibrio biologico ed ecologico; k) i controlli sanitari sulla produzione dell'energia termoelettrica e nucleare e sulla produzione, il commercio e l'impiego delle sostanze radioattive; l) il prelievo di parti di cadavere, la loro utilizzazione e il trapianto di organi limitatamente alle funzioni di cui alla legge 2 dicembre 1975, n. 644; m) la disciplina generale del lavoro e della produzione ai fini della prevenzione degli infortuni sul lavoro e delle malattie professionali; n) l'omologazione di macchine, di impianti e di mezzi personali di protezione; o) l'istituto superiore di sanita', secondo le norme di cui alla legge 7 agosto 1973, n. 519, ed alla presente legge; p) l'Istituto superiore per la prevenzione e la sicurezza del lavoro secondo le norme previste dalla presente legge; q) la fissazione dei requisiti per la determinazione dei profili professionali degli operatori sanitari; le disposizioni generali per la durata e la conclusione dei corsi; la determinazione dei requisiti necessari per la ammissione alle scuole, nonche' dei requisiti per l'esercizio delle professioni mediche e sanitarie ausiliarie; r) il riconoscimento e la equiparazione dei servizi sanitari prestati in Italia e all'estero dagli operatori sanitari ai fini dell'ammissione ai concorsi e come titolo nei concorsi stessi; s) gli ordini e i collegi professionali; t) il riconoscimento delle proprieta' terapeutiche delle acque minerali e termali e la pubblicita' relativa alla loro utilizzazione a scopo sanitario; u) la individuazione delle malattie infettive e diffusive del bestiame per le quali, in tutto il territorio nazionale, sono disposti l'obbligo di abbattimento e, se del caso, la distruzione degli animali infetti o sospetti di infezione o di contaminazione; la determinazione degli interventi obbligatori in materia di zooprofilassi; le prescrizioni inerenti all'impiego dei principi attivi, degli additivi e delle sostanze minerali e chimico-industriali nei prodotti destinati all'alimentazione zootecnica, nonche' quelle relative alla produzione e alla commercializzazione di questi ultimi prodotti; v) ((LETTERA ABROGATA DAL D.LGS. 15 MARZO 2010, N.66)); z) i servizi sanitari istituiti per ((...)) i Corpi di polizia, per il Corpo degli agenti di custodia e per il Corpo nazionale dei vigili del fuoco, nonche' i servizi dell'Azienda autonoma delle ferrovie dello Stato relativi all'accertamento tecnico-sanitario delle condizioni del personale dipendente.

### Art. 7. - (Funzioni delegate alle regioni)

E' delegato alle regioni l'esercizio delle funzioni amministrative concernenti: a) la profilassi delle malattie infettive e diffusive, di cui al precedente articolo 6, lettera b); b) l'attuazione degli adempimenti disposti dall'autorita' sanitaria statale ai sensi della lettera u) del precedente articolo 6; c) i controlli sulla produzione, detenzione, commercio e impiego dei gas tossici e delle altre sostanze pericolose; d) il controllo dell'idoneita' dei locali ed attrezzature per il commercio e il deposito delle sostanze radioattive naturali ed artificiali e di apparecchi generatori di radiazioni ionizzanti; il controllo sulla radioattivita' ambientale; e) i controlli sulla produzione e sul commercio dei prodotti dietetici, degli alimenti per la prima infanzia e la cosmesi. Le regioni provvedono all'approvvigionamento di sieri e vaccini necessari per le vaccinazioni obbligatorie in base ad un programma concordato con il Ministero della sanita'. Il Ministero della sanita' provvede, se necessario, alla costituzione ed alla conservazione di scorte di sieri, di vaccini, di presidi profilattici e di medicinali di uso non ricorrente, da destinare alle regioni per esigenze particolari di profilassi e cura delle malattie infettive, diffusive e parassitarie. Le regioni esercitano le funzioni delegate di cui al presente articolo mediante subdelega ai comuni. In relazione alle funzioni esercitate dagli uffici di sanita' marittima, aerea e di frontiera e dagli uffici veterinari di confine, di porto e di aeroporto, il Governo e' delegato ad emanare, entro un anno dalla entrata in vigore della presente legge, uno o piu' decreti per ristrutturare e potenziare i relativi uffici nel rispetto dei seguenti criteri: a) si procedera' ad una nuova distribuzione degli uffici nel territorio, anche attraverso la costituzione di nuovi uffici, in modo da attuare il piu' efficiente ed ampio decentramento delle funzioni; b) in conseguenza, saranno rideterminate le dotazioni organiche dei posti previsti dalla Tabella XIX, quadri B, C e D, allegata al decreto del Presidente della Repubblica 30 giugno 1972, n. 748, nonche' le dotazioni organiche dei ruoli delle carriere direttive, di concetto, esecutive, ausiliarie e degli operatori, prevedendo, per la copertura dei posti vacanti, concorsi a base regionale. L'esercizio della delega alle regioni, per le funzioni indicate nel quarto comma, in deroga all'articolo 34 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, si attua a partire dal 1 gennaio 1981. ((4))

--------------- AGGIORNAMENTO (4) La L. 29 febbraio 1980, n. 33, ha disposto (con l'art. 2, comma 1) che "Le deleghe conferite al Governo con gli articoli 7, 42 e 70 della legge 23 dicembre 1978, n. 833, scadute il 23 dicembre 1979, nonche' le deleghe conferite con gli articoli 23 e 37 della legge medesima, scadute il 31 dicembre 1979, sono rinnovate fino al 31 luglio 1980".

### Art. 8. - (Consiglio sanitario nazionale)

E' istituito il Consiglio sanitario nazionale con funzioni di consulenza e di proposta nei confronti del Governo per la determinazione delle linee generali della politica sanitaria nazionale e per l'elaborazione e la attuazione del piano sanitario nazionale. Il Consiglio e' sentito obbligatoriamente in ordine ai programmi globali di prevenzione anche primaria, alla determinazione dei livelli di prestazioni sanitarie stabiliti con le modalita' di cui al secondo comma dell'articolo 3 e alla ripartizione degli stanziamenti di cui all'articolo 51, nonche' alle fasi di attuazione del servizio sanitario nazionale e alla programmazione del fabbisogno di personale sanitario necessario alle esigenze del servizio sanitario nazionale. Esso predispone una relazione annuale sullo stato sanitario del paese, sulla quale il Ministro della sanita' riferisce al Parlamento entro il 31 marzo di ogni anno. Il Consiglio sanitario nazionale, nominato con decreto del Presidente della Repubblica, su proposta del Ministro della sanita', per la durata di un quinquennio, e' presieduto dal Ministro della sanita' ed e' composto: a) da un rappresentante per ciascuna regione e, per quanto concerne la regione Trentino-Alto Adige, da un rappresentante della provincia di Trento e da un rappresentante della provincia di Bolzano; b) da tre rappresentanti del Ministero della sanita' e da un rappresentante per ciascuno dei seguenti Ministeri: lavoro e previdenza sociale; pubblica istruzione; interno; difesa; tesoro; bilancio e programmazione economica; agricoltura e foreste; industria, commercio e artigianato; marina mercantile; da un rappresentante designato dal Ministro per il coordinamento delle iniziative per la ricerca scientifica e tecnologica; c) dal direttore dell'Istituto superiore di sanita', dal direttore dell'Istituto superiore per la prevenzione e la sicurezza del lavoro, da un rappresentante del Consiglio nazionale delle ricerche e da dieci esperti in materia sanitaria designati dal CNEL, tenendo presenti i criteri di rappresentativita' e competenze funzionali al servizio sanitario nazionale. Per ogni membro effettivo deve essere nominato, con le stesse modalita' sopra previste, un membro supplente che subentra in caso di assenza o impedimento del titolare. Il Consiglio elegge tra i suoi componenti un vicepresidente. L'articolazione in sezioni, le modalita' di funzionamento e le funzioni di segreteria del Consiglio sono disciplinate con regolamento emanato dal Ministro della sanita', sentito il Consiglio stesso.

### Art. 9. - (istituto superiore di sanita')

L'Istituto superiore di sanita' e' organo tecnico-scientifico del servizio sanitario nazionale dotato di strutture e ordinamenti particolari e di autonomia scientifica. Esso dipende dal Ministro della sanita' e collabora con le unita' sanitarie locali, tramite le regioni, e con le regioni stesse, su richiesta di queste ultime, fornendo nell'ambito dei propri compiti istituzionali le informazioni e le consulenze eventualmente necessarie. Esso esplica attivita' di consulenza nelle materie di competenza dello Stato, di cui al precedente articolo 6 della presente legge, ad eccezione di quelle previste dalle lettere g), k), m) e n). Le modalita' della collaborazione delle regioni con l'Istituto superiore di sanita' sono disciplinate nell'ambito dell'attivita' governativa di indirizzo e coordinamento di cui all'articolo 5. L'Istituto per l'assolvimento dei propri compiti istituzionali, ha facolta' di accedere agli impianti produttivi nonche' ai presidi e servizi sanitari per compiervi gli accertamenti e i controlli previsti dall'articolo 1 della legge 7 agosto 1973, n. 419. Tale facolta' e' inoltre consentita all'Istituto su richiesta delle regioni. L'Istituto, in attuazione di un programma predisposto dal Ministro della sanita', organizza, in collaborazione con le regioni, le universita' e le altre istituzioni pubbliche a carattere scientifico, corsi di specializzazione ed aggiornamento in materia di sanita' pubblica per gli operatori sanitari con esclusione del personale tecnico-infermieristico; esso inoltre appronta ed aggiorna periodicamente l'Inventario nazionale delle sostanze chimiche corredato dalle caratteristiche chimico-fisiche e tossicologiche necessarie per la valutazione del rischio sanitario connesso alla loro presenza nell'ambiente; predispone i propri programmi di ricerca tenendo conto degli obiettivi della programmazione sanitaria nazionale e delle proposte avanzate dalle regioni. Tali programmi sono approvati dal Ministro della sanita', sentito il Consiglio sanitario nazionale. L'Istituto svolge l'attivita' di ricerca avvalendosi degli istituti pubblici a carattere scientifico e delle altre istituzioni pubbliche operanti nel settore; possono inoltre esser chiamati a collaborare istituti privati di riconosciuto valore scientifico. ((COMMA ABROGATO DAL D.L. 30 DICEMBRE 1979, N. 663, CONVERTITO CON MODIFICAZIONI DALLA L. 29 FEBBRAIO 1980, N. 33)). Il secondo comma dell'articolo 4 della legge 7 agosto 1973, n. 519, e' sostituito dal seguente: "La suddivisione dell'Istituto in laboratori, il loro numero e le loro competenze sono stabilite con decreto del Ministro della sanita', su proposta del Comitato scientifico e del Comitato amministrativo secondo le modalita' previste dall'articolo 62 della legge 7 agosto 1973, n. 519 La lettera b), primo comma, dell'articolo 13 della legge 7 agosto 1973, n. 519, e' sostituita dalla seguente: "b) da dieci esperti nominati per tre anni con decreto del Ministro della sanita' tra personalita' operanti nell'ambito di universita' e istituti a carattere scientifico, italiani ed eventualmente stranieri, o nell'ambito del Consiglio nazionale delle ricerche, e da dieci esperti di nazionalita' italiana nominati per tre anni, con decreto del Ministro della sanita', tra personalita' operanti nell'ambito delle universita' e dei presidi igienico-sanitari regionali. Tali esperti sono nominati su proposta del Consiglio sanitario nazionale".

### Art. 10. - (L'organizzazione territoriale)

Alla gestione unitaria della tutela della salute si provvede in modo uniforme sull'intero territorio nazionale mediante una rete completa di unita' sanitarie locali. L'unita' sanitaria locale e' il complesso dei presidi, degli uffici e dei servizi dei comuni, singoli o associati, e delle comunita' montane i quali in un ambito territoriale determinato assolvono ai compiti del servizio sanitario nazionale di cui alla presente legge. Sulla base dei criteri stabiliti con legge regionale i comuni, singoli o associati, o le comunita' montane articolano le unita' sanitarie locali in distretti sanitari di base, quali strutture tecnico-funzionali per l'erogazione dei servizi di primo livello e di pronto intervento.

### Art. 11. - (Competenze regionali)

Le regioni esercitano le funzioni legislative in materia di assistenza sanitaria ed ospedaliera nel rispetto dei principi fondamentali stabiliti dalle leggi dello Stato ed esercitano le funzioni amministrative proprie o loro delegate. Le leggi regionali devono in particolare conformarsi ai seguenti principi: a) coordinare l'intervento sanitario con gli interventi negli altri settori economici, sociali e di organizzazione del territorio di competenza delle regioni; b) unificare l'organizzazione sanitaria su base territoriale e funzionale adeguando la normativa alle esigenze delle singole situazioni regionali. c) assicurare la corrispondenza tra costi dei servizi e relativi benefici. Le regioni svolgono la loro attivita' secondo il metodo della programmazione pluriennale e della piu' ampia partecipazione democratica, in armonia con le rispettive norme statutarie. A tal fine, nell'ambito dei programmi regionali di sviluppo, predispongono piani sanitari regionali, previa consultazione degli enti locali, delle universita' presenti nel territorio regionale, delle organizzazioni maggiormente rappresentative delle forze sociali e degli operatori della sanita', nonche' degli organi della sanita' militare territorialmente competenti. Con questi ultimi le regioni possono concordare: a) l'uso delle strutture ospedaliere militari in favore delle popolazioni civili nei casi di calamita', epidemie e per altri scopi che si ritengano necessari; b) l'uso dei servizi di prevenzione delle unita' sanitarie locali al fine di contribuire al miglioramento delle condizioni igienico-sanitarie dei militari. Le regioni, sentiti i comuni interessati, determinano gli ambiti territoriali delle unita' sanitarie locali, che debbono coincidere con gli ambiti territoriali di gestione dei servizi sociali. All'atto della determinazione degli ambiti di cui al comma precedente, le regioni provvedono altresi' ad adeguare la delimitazione dei distretti scolastici e di altre unita' di servizio in modo che essi, di regola, coincidano.

### Art. 12. - (Attribuzioni delle province)

Fino all'entrata in vigore della legge di riforma delle autonomie locali spetta alle province approvare, nell'ambito dei piani sanitari regionali, la localizzazione dei presidi e servizi sanitari ed esprimere parere sulle delimitazioni territoriali di cui al quinto comma del precedente articolo 11.

### Art. 13. - (Attribuzioni dei comuni)

Sono attribuite ai comuni tutte le funzioni amministrative in materia di assistenza sanitaria ed ospedaliera che non siano espressamente riservate allo Stato ed alle regioni. I comuni esercitano le funzioni di cui alla presente legge in forma singola o associata mediante le unita' sanitarie locali, ferme restando le attribuzioni di ciascun sindaco quale autorita' sanitaria locale. I comuni, singoli o associati, assicurano, anche con riferimento alla legge 8 aprile 1976, n. 278, e alle leggi regionali, la piu' ampia partecipazione degli operatori della sanita', delle formazioni sociali esistenti sul territorio, dei rappresentanti degli interessi originari definiti ai sensi della legge 12 febbraio 1968, n. 132, e dei cittadini, a tutte le fasi della programmazione dell'attivita' delle unita' sanitarie locali e alla gestione sociale dei servizi sanitari, nonche' al controllo della loro funzionalita' e rispondenza alle finalita' del servizio sanitario nazionale e agli obiettivi dei piani sanitari triennali delle regioni di cui all'articolo 55. Disciplinano inoltre, anche ai fini dei compiti di educazione sanitaria propri dell'unita' sanitaria locale, la partecipazione degli utenti direttamente interessati all'attuazione dei singoli servizi.

### Art. 14. - (Unita' sanitarie locali)

L'ambito territoriale di attivita' di ciascuna unita' sanitaria locale e' delimitato in base a gruppi di popolazione di regola compresi tra 50.000 e 200.000 abitanti, tenuto conto delle caratteristiche geomorfologiche e socio-economiche della zona. Nel caso di aree a popolazione particolarmente concentrata o sparsa e anche al fine di consentire la coincidenza con un territorio comunale adeguato, sono consentiti limiti piu' elevati o, in casi particolari, piu' ristretti. Nell'ambito delle proprie competenze, l'unita' sanitaria locale provvede in particolare: a) all'educazione sanitaria; b) ((LETTERA ABROGATA DAL D.P.R. 5 GIUGNO 1993, N. 177 A SEGUITO DI REFERENDUM POPOLARE)); c) alla prevenzione individuale e collettiva delle malattie fisiche e psichiche; d) alla protezione sanitaria materno-infantile, all'assistenza pediatrica e alla tutela del diritto alla procreazione cosciente e responsabile; e) all'igiene e medicina scolastica negli istituti di istruzione pubblica e privata di ogni ordine e grado; f) all'igiene e medicina del lavoro, nonche' alla prevenzione degli infortuni sul lavoro e delle malattie professionali; g) alla medicina dello sport e alla tutela sanitaria delle attivita' sportive; h) all'assistenza medico-generica e infermieristica, domiciliare e ambulatoriale; i) all'assistenza medico-specialistica e infermieristica, ambulatoriale e domiciliare, per le malattie fisiche e psichiche; l) all'assistenza ospedaliera per le malattie fisiche e psichiche; m) alla riabilitazione; n) all'assistenza farmaceutica e alla vigilanza sulle farmacie; o) all'igiene della produzione, lavorazione, distribuzione e commercio degli alimenti e delle bevande; p) alla profilassi e alla polizia veterinaria; alla ispezione e alla vigilanza veterinaria sugli animali destinati ad alimentazione umana, sugli impianti di macellazione e di trasformazione, sugli alimenti di origine animale, sull'alimentazione zootecnica e sulle malattie trasmissibili dagli animali all'uomo, sulla riproduzione, allevamento e sanita' animale, sui farmaci di uso veterinario; q) agli accertamenti, alle certificazioni ed a ogni altra prestazione medico-legale spettanti al servizio sanitario nazionale, con esclusione di quelle relative ai servizi di cui alla lettera z) dell'articolo 6.

### Art. 15. - (Struttura e funzionamento delle unita' sanitarie locali)

L'unita' sanitaria locale, di cui all'articolo 10, secondo comma, della presente legge, e' una struttura operativa dei comuni, singoli o associati, e delle comunita' montane Organi della unita' sanitaria locale sono: 1) l'assemblea generale; ((19)) 2) il comitato di gestione e il suo presidente; ((19)) 3) il collegio dei revisori, composto di tre membri, uno dei quali designato dal Ministro del tesoro e uno dalla regione. La legge regionale disciplina i compiti e le modalita' di funzionamento del collegio. Il collegio dei revisori e' tenuto a sottoscrivere i rendiconti di cui all'articolo 50, secondo comma, e a redigere una relazione trimestrale sulla gestione amministrativo-contabile delle unita' sanitarie locali da trasmettere alla regione e ai Ministeri della sanita' e del tesoro. In armonia con la legge 8 aprile 1976, n. 278, il comune puo' stabilire forme di partecipazione dei consigli circoscrizionali all'attivita' delle unita' sanitarie locali e quando il territorio di queste coincide con quello delle circoscrizioni puo' attribuire ai consigli circoscrizionali poteri che gli sono conferiti dalla presente legge. L'assemblea generale dell'associazione dei comuni di cui alla lettera b) del presente articolo e' formata dai rappresentanti dei comuni associati, eletti con criteri di proporzionalita'. Il numero dei rappresentanti viene determinato con legge regionale. La legge regionale detta norme per assicurare forme di preventiva consultazione dei singoli comuni sulle decisioni di particolare rilievo dell'associazione dei comuni. L'assemblea generale elegge, con voto limitato, il comitato di gestione, il quale nomina il proprio presidente. Il comitato di gestione compie tutti gli atti di amministrazione dell'unita' sanitaria locale. Gli atti relativi all'approvazione dei bilanci e dei conti consuntivi, dei piani e programmi che impegnino piu' esercizi, della pianta organica del personale, dei regolamenti, delle convenzioni, sono predisposti dal comitato di gestione e vengono approvati dalle competenti assemblee generali. Le competenze del comitato di gestione e del suo presidente sono attribuite rispettivamente, alla giunta e al presidente della comunita' montana, quando il territorio di questa coincida con l'ambito territoriale dell'unita' sanitaria locale. La legge regionale detta norme per l'organizzazione, la gestione e il funzionamento delle unita' sanitarie locali e dei loro servizi e, in particolare, per: 1) assicurare l'autonomia tecnico-funzionale dei servizi dell'unita' sanitaria locale, il loro coordinamento e la partecipazione degli operatori, anche mediante l'istituzione di specifici organi di consultazione tecnica; 2) prevedere un ufficio di direzione dell'unita' sanitaria locale, articolato distintamente per la responsabilita' sanitaria ed amministrativa e collegialmente preposto all'organizzazione, al coordinamento e al funzionamento di tutti i servizi e alla direzione del personale. Per il personale preposto all'ufficio di direzione dell'unita' sanitaria locale le norme delegate di cui al terzo comma del successivo articolo 47, devono prevedere specifici requisiti di professionalita' e di esperienza in materia di tutela della salute e di organizzazione sanitaria; 3) predisporre bilanci e conti consuntivi da parte dell'unita' sanitaria locale, secondo quanto previsto dal primo comma dell'articolo 50; 4) emanare il regolamento organico del personale dell'unita' sanitaria locale e le piante organiche dei diversi presidi e servizi, anche con riferimento alle norme di cui all'articolo 47; 5) predisporre l'organizzazione e la gestione dei presidi e dei servizi multizonali di cui al successivo articolo 18, fermo il principio dell'intesa con i comuni interessati. Il segretario della comunita' montana assolve anche alle funzioni di segretario per gli atti svolti dalla comunita' montana in funzione di unita' sanitaria locale ai sensi del terzo comma, punto c), del presente articolo. La legge regionale stabilisce altresi' norme per la gestione coordinata ed integrata dei servizi dell'unita' sanitaria locale con i servizi sociali esistenti nel territorio.

--------------- AGGIORNAMENTO (19) La L. 15 gennaio 1986, n. 4, ha disposto (con l'articolo unico) che: "In attesa della riforma istituzionale delle unita' sanitarie locali, gli organi delle stesse, previsti dal secondo comma, punti 1) e 2), dell'articolo 15 della legge 23 dicembre 1978, n. 833, e successive modificazioni e integrazioni, sono cosi' sostituiti: a) l'assemblea generale e' soppressa. Le relative competenze sono svolte dal consiglio comunale o dall'assemblea generale della comunita' montana o dall'assemblea dell'associazione intercomunale costituita secondo le procedure previste dall'articolo 25 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, in relazione all'ambito territoriale di ciascuna unita' sanitaria locale. Il numero dei componenti dell'assemblea dell'associazione intercomunale e' determinato dalla regione e non puo' superare quello dei componenti assegnati al consiglio di un comune che abbia un numero di abitanti pari a quello dei comuni associati. I componenti dell'anzidetta assemblea sono eletti tra i consiglieri comunali dei comuni associati con voto limitato. Su proposta del comitato di gestione di cui alla successiva lettera b), il consiglio comunale o l'assemblea dell'associazione intercomunale o l'assemblea della comunita' montana deliberano in materia di: 1) bilancio preventivo, suo assestamento e conto consuntivo; 2) spese che vincolano il bilancio oltre l'anno; 3) adozione complessiva delle piante organiche; 4) convenzioni di cui all'articolo 44 della legge 23 dicembre 1978, n. 833; 5) articolazione dei distretti sanitari di base. L'approvazione anche con modificazioni di detti atti deve intervenire nel termine di quarantacinque giorni dalla trasmissione delle proposte; b) il comitato di gestione e' composto dal presidente e da quattro o sei membri, sulla base di quanto stabilito dalla regione secondo le dimensioni dell'unita' sanitaria locale, eletti, a maggioranza, con separate votazioni, dal consiglio comunale o dall'assemblea della associazione intercomunale, anche fuori del proprio seno, tra cittadini aventi esperienza di amministrazione e direzione, documentata da un curriculum, che deve, essere depositato, a cura di uno o piu' gruppi presenti nel consiglio comunale o nella assemblea della associazione intercomunale, cinque giorni prima della elezione. Qualora l'ambito territoriale della unita' sanitaria locale coincida con quello della comunita' montana, le funzioni del presidente e del comitato di gestione sono svolte rispettivamente dal presidente e dalla giunta della comunita' montana".

### Art. 16. - (Servizi veterinari)

La legge regionale stabilisce norme per il riordino dei servizi veterinari a livello regionale nell'ambito di ciascuna unita' sanitaria locale o in un ambito territoriale piu' ampio, tenendo conto della distribuzione e delle attitudini produttive del patrimonio zootecnico, della riproduzione animale, della dislocazione e del potenziale degli impianti di macellazione, di lavorazione e di conservazione delle carni e degli altri prodotti di origine animale, della produzione dei mangimi e degli integratori, delle esigenze della zooprofilassi, della lotta contro le zoonosi e della vigilanza sugli alimenti di origine animale. La legge regionale individua anche le relative strutture multizonali e ne regola il funzionamento ai sensi dell'articolo 18.

### Art. 17. - (Requisiti e struttura interna degli ospedali)

Gli stabilimenti ospedalieri sono strutture delle unita' sanitarie locali, dotate dei requisiti minimi di cui all'articolo 19, primo comma, della legge 12 febbraio 1968, n. 132. Le Regioni nell'ambito della programmazione sanitaria disciplinano con legge l'articolazione dell'ordinamento degli ospedali in dipartimenti, in base al principio dell'interazione tra le divisioni, sezioni e servizi affini e complementari, a quello del collegamento tra servizi ospedalieri ed extra ospedalieri in rapporto alle esigenze di definiti ambiti territoriali, nonche' a quello della gestione dei dipartimenti stessi sulla base della integrazione delle competenze in modo da valorizzare anche il lavoro di gruppo. Tale disciplina tiene conto di quanto previsto all'articolo 34 della presente legge.

### Art. 18. - (Presidi e servizi multizonali)

La legge regionale individua, nell'ambito della programmazione sanitaria, i presidi e i servizi sanitari ospedalieri ed extra-ospedalieri che, per le finalita' specifiche perseguite e per le caratteristiche tecniche e specialistiche, svolgono attivita' prevalentemente rivolte a territori la cui estensione includa piu' di una unita' sanitaria locale e ne disciplina l'organizzazione. La stessa legge attribuisce la gestione dei presidi e dei servizi di cui al precedente comma alla unita' sanitaria locale nel cui territorio sono ubicati e stabilisce norme particolari per definire: a) il collegamento funzionale ed il coordinamento di tali presidi e servizi con quelli delle unita' sanitarie locali interessate, attraverso idonee forme di consultazione dei rispettivi organi di gestione; b) gli indirizzi di gestione dei predetti presidi e servizi e le procedure per l'acquisizione degli elementi idonei ad accertarne l'efficienza operativa; c) la tenuta di uno specifico conto di gestione allegato al conto di gestione generale dell'unita' sanitaria locale competente per territorio; d) la composizione dell'organo di gestione dell'unita' sanitaria locale competente per territorio e la sua eventuale articolazione in riferimento alle specifiche esigenze della gestione.

## PRESTAZIONI E FUNZIONI

### Art. 19. - (Prestazioni delle unita' sanitarie locali)

Le unita' sanitarie locali provvedono ad erogare le prestazioni di prevenzione, di cura, di riabilitazione e di medicina legale, assicurando a tutta la popolazione i livelli di prestazioni sanitarie stabiliti ai sensi del secondo comma dell'articolo 3. Ai cittadini e' assicurato il diritto alla libera scelta del medico e del luogo di cura nei limiti oggettivi dell'organizzazione dei servizi sanitari. Gli utenti del servizio sanitario nazionale sono iscritti in appositi elenchi periodicamente aggiornati presso l'unita' sanitaria locale nel cui territorio hanno la residenza. Gli utenti hanno diritto di accedere, per motivate ragioni o in casi di urgenza o di temporanea dimora in luogo diverso da quello abituale, ai servizi di assistenza di qualsiasi unita' sanitaria locale. I militari hanno diritto di accedere ai servizi di assistenza delle localita' ove prestano servizio con le modalita' stabilite nei regolamenti di sanita' militare. Gli emigrati, che rientrino temporaneamente in patria, hanno diritto di accedere ai servizi di assistenza della localita' in cui si trovano.

### Art. 20. - (Attivita' di prevenzione)

Le attivita' di prevenzione comprendono: a) la individuazione, l'accertamento ed il controllo dei fattori di nocivita', di pericolosita' e di deterioramento negli ambienti ((...)) di lavoro, in applicazione delle norme di legge vigenti in materia e al fine di garantire il rispetto dei limiti massimi inderogabili di cui all'ultimo comma dell'articolo 4, nonche' al fine della tenuta dei registri di cui al penultimo comma dell'articolo 27; i predetti compiti sono realizzati anche mediante collaudi e verifiche di macchine, impianti e mezzi di protezione prodotti, installati o utilizzati nel territorio dell'unita' sanitaria locale in attuazione delle funzioni definite dall'articolo 14; ((21)) b) la comunicazione dei dati accertati e la diffusione della loro conoscenza, anche a livello di luogo di lavoro e di ambiente di residenza, sia direttamente che tramite gli organi del decentramento comunale, ai fini anche di una corretta gestione degli strumenti informativi di cui al successivo articolo 27, e le rappresentanze sindacali; c) la indicazione delle misure idonee all'eliminazione dei fattori di rischio ed al risanamento di ambienti ((...)) di lavoro, in applicazione delle norme di legge vigenti in materia, e l'esercizio delle attivita' delegate ai sensi del primo comma, lettere a), b), c), d) ed e) dell'articolo 7; ((21)) d) la formulazione di mappe di rischio con l'obbligo per le aziende di comunicare le sostanze presenti nel ciclo produttivo e le loro caratteristiche tossicologiche ed i possibili effetti sull'uomo e sull'ambiente; e) la profilassi degli eventi morbosi, attraverso l'adozione delle misure idonee a prevenirne l'insorgenza; f) la verifica, secondo le modalita' previste dalle leggi e dai regolamenti, della compatibilita' dei piani urbanistici e dei progetti di insediamenti industriali e di attivita' produttive in genere con le esigenze di tutela dell'ambiente sotto il profilo igienico-sanitario e di difesa della salute della popolazione e dei lavoratori interessati. Nell'esercizio delle funzioni ad esse attribuite per l'attivita' di prevenzione le unita' sanitarie locali, garantendo per quanto alla lettera d) del precedente comma la tutela del segreto industriale, si avvalgono degli operatori sia dei propri servizi di igiene, sia dei presidi specialistici multizonali di cui al successivo articolo 22, sia degli operatori che, nell'ambito delle loro competenze tecniche e funzionali, erogano le prestazioni di diagnosi, cura e riabilitazione. Gli interventi di prevenzione all'interno degli ambienti di lavoro, concernenti la ricerca, l'elaborazione e l'attuazione di misure necessarie ed idonee a tutelare la salute e l'integrita' fisica dei lavoratori, connesse alla particolarita' del lavoro e non previste da specifiche norme di legge, sono effettuati sulla base di esigenze verificate congiuntamente con le rappresentanze sindacali ed il datore di lavoro, secondo le modalita' previste dai contratti o accordi collettivi applicati nell'unita' produttiva.

--------------- AGGIORNAMENTO (21) Il D.P.R. 5 giugno 1993, n. 177, ha disposto (con l'art. 1, comma 2) che l'abrogazione ha effetto decorsi sessanta giorni dalla data di pubblicazione del presente decreto nella Gazzetta Ufficiale.

### Art. 21. - (Organizzazione dei servizi di prevenzione)

In relazione agli standards fissati in sede nazionale, all'unita' sanitaria locale sono attribuiti, con decorrenza 1 gennaio 1980, i compiti attualmente svolti dall'Ispettorato del lavoro in materia di prevenzione, di igiene e di controllo sullo stato di salute dei lavoratori, in applicazione di quanto disposto dall'articolo 27 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616. Per la tutela della salute dei lavoratori ((...)) le unita' sanitarie locali organizzano propri servizi ((...)) di medicina del lavoro anche prevedendo, ove essi non esistano, presidi all'interno delle unita' produttive. ((21)) In applicazione di quanto disposto nell'ultimo comma dell'articolo 27 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, spetta al prefetto stabilire, su proposta del presidente della regione, quali addetti ai servizi di ciascuna unita' sanitaria locale, nonche' ai presidi e servizi di cui al successivo articolo 22 assumano ai sensi di polizia giudiziaria, in relazione alle funzioni ispettive e di controllo da essi esercitate relativamente all'applicazione della legislazione sulla sicurezza del lavoro. Al personale di cui al comma precedente e' esteso il potere d'accesso attribuito agli ispettori del lavoro dall'articolo 8, secondo comma, nonche' la facolta' di diffida prevista dall'articolo 9 del decreto del Presidente della Repubblica 19 marzo 1955, n. 520. Contro i provvedimenti adottati dal personale ispettivo, nell'esercizio delle funzioni di cui al terzo comma, e' ammesso ricorso al presidente della giunta regionale che decide, sentite le organizzazioni dei lavoratori e dei datori di lavoro. Il presidente della giunta puo' sospendere l'esecuzione dell'atto impugnato.

--------------- AGGIORNAMENTO (21) Il D.P.R. 5 giugno 1993, n. 177, ha disposto (con l'art. 1, comma 2) che l'abrogazione ha effetto decorsi sessanta giorni dalla data di pubblicazione del presente decreto nella Gazzetta Ufficiale.

### Art. 22. - (Presidi e servizi multizonali di prevenzione)

La legge regionale, in relazione alla ubicazione ed alla consistenza degli impianti industriali ed alle peculiarita' dei processi produttivi agricoli, artigianali e di lavoro: a) individua le unita' sanitarie locali in cui sono istituiti presidi e servizi multizonali per il controllo e la tutela dell'igiene ambientale e per la prevenzione degli infortuni sul lavoro e delle malattie professionali; b) definisce le caratteristiche funzionali e interdisciplinari di tali presidi e servizi multizonali; c) prevede le forme di coordinamento degli stessi con i servizi di igiene ambientale e di igiene e medicina del lavoro di ciascuna unita' sanitaria locale. I presidi e i servizi multizonali di cui al comma precedente sono gestiti dall'unita' sanitaria locale nel cui territorio sono ubicati, secondo le modalita' di cui all'articolo 18.

### Art. 23. - (Delega per la istituzione dell'Istituto superiore per la prevenzione e la sicurezza del lavoro)

Il Governo e' delegato ad emanare, entro il 31 dicembre 1979, su proposta del Ministro della sanita', di concerto con i Ministri del lavoro e della previdenza sociale, dell'industria, commercio e artigianato e dell'agricoltura e foreste, un decreto avente valore di legge ordinaria per la istituzione dell'istituto superiore per la prevenzione e la sicurezza del lavoro, da porre alle dipendenze del Ministro della sanita'. Nel suo organo di amministrazione sono rappresentati i Ministeri del lavoro e della previdenza sociale, dell'industria, commercio e artigianato e dell'agricoltura e foreste ed i suoi programmi di attivita' sono approvati dal CIPE, su proposta del Ministro della sanita', sentito il Consiglio sanitario nazionale. L'esercizio della delega deve uniformarsi ai seguenti principi e criteri direttivi: a) assicurare la collocazione dell'Istituto nel servizio sanitario nazionale per tutte le attivita' tecnico-scientifiche e tutte le funzioni consultive che riguardano la prevenzione delle malattie professionali e degli infortuni sul lavoro; b) prevedere le attivita' di consulenza tecnico-scientifica che competono all'Istituto nei confronti degli organi centrali dello Stato preposti ai settori del lavoro e della produzione. All'Istituto sono affidati compiti di ricerca, di studio, di sperimentazione e di elaborazione delle tecniche per la prevenzione e la sicurezza del lavoro in stretta connessione con l'evoluzione tecnologica degli impianti, dei materiali, delle attrezzature e dei processi produttivi, nonche' di determinazione dei criteri di sicurezza e dei relativi metodi di rilevazione ai fini della omologazione di macchine, di impianti, di apparecchi, di strumenti e di mezzi personali di protezione e dei prototipi. L'Istituto svolge, nell'ambito delle proprie attribuzione istituzionali, attivita' di consulenza nelle materie di competenza dello Stato di cui all'articolo 6, lettere g), i), k), m), n), della presente legge, e in tutte le materie di competenza dello Stato e collabora con le unita' sanitarie locali tramite le regioni e con le regioni stesse, su richiesta di queste ultime, fornendo le informazioni e le consulenze necessarie per l'attivita' dei servizi di cui agli articoli 21 e 22. Le modalita' della collaborazione delle regioni con l'Istituto sono disciplinate nell'ambito dell'attivita' governativa di indirizzo e di coordinamento di cui all'articolo 5. L'Istituto ha facolta' di accedere nei luoghi di lavoro per compiervi rilevamenti e sperimentazioni per l'assolvimento dei propri compiti istituzionali. L'accesso nei luoghi di lavoro e' inoltre consentito, su richiesta delle regioni, per l'espletamento dei compiti previsti dal precedente comma. L'Istituto organizza la propria attivita' secondo criteri di programmazione. I programmi di ricerca dell'Istituto relativi alla prevenzione delle malattie e degli infortuni sul lavoro sono predisposti tenendo conto degli obiettivi della programmazione sanitaria nazionale e delle proposte delle regioni. L'Istituto, anche ai fini dei programmi di ricerca e di sperimentazione, opera in stretto collegamento con l'Istituto superiore di sanita' e coordina le sue attivita' con il Consiglio nazionale delle ricerche e con il Comitato nazionale per l'energia nucleare. Esso si avvale inoltre della collaborazione degli istituti di ricerca delle universita' e di altre istituzioni pubbliche. Possono essere chiamati a collaborare all'attuazione dei suddetti programmi istituti privati di riconosciuto valore scientifico. L'Istituto cura altresi' i collegamenti con istituzioni estere che operano nel medesimo settore. Le qualifiche professionali del corpo dei tecnici e ricercatori dell'Istituto e la sua organizzazione interna, devono mirare a realizzare l'obiettivo della unitarieta' della azione di prevenzione nei suoi aspetti interdisciplinari. L'Istituto collabora alla formazione ed all'aggiornamento degli operatori dei servizi di prevenzione delle unita' sanitarie locali. L'Istituto provvede altresi' ad elaborare i criteri per le norme di prevenzione degli incendi interessanti le macchine, gli impianti e le attrezzature soggette ad omologazione, di concerto con i servizi di protezione civile del Ministero dell'interno. Nulla e' innovato per quanto concerne le disposizioni riguardanti le attivita' connesse con l'impiego pacifico dell'energia nucleare. ((4))

--------------- AGGIORNAMENTO (4) La L. 29 febbraio 1980, n. 33, ha disposto (con l'art. 2, comma 1) che "Le deleghe conferite al Governo con gli articoli 7, 42 e 70 della legge 23 dicembre 1978, n. 833, scadute il 23 dicembre 1979, nonche' le deleghe conferite con gli articoli 23 e 37 della legge medesima, scadute il 31 dicembre 1979, sono rinnovate fino al 31 luglio 1980".

### Art. 24. - (Norme in materia di igiene e sicurezza negli ambienti di lavoro e di vita e di omologazioni)

Il Governo e' delegato ad emanare, entro il 31 dicembre 1979, su proposta del Ministro della sanita', con il concerto dei Ministri competenti, un testo unico in materia di sicurezza del lavoro, che riordini la disciplina generale del lavoro e della produzione al fine della prevenzione degli infortuni sul lavoro e delle malattie professionali, nonche' in materia di omologazioni, unificando e innovando la legislazione vigente tenendo conto delle caratteristiche della produzione al fine di garantire la salute e l'integrita' fisica dei lavoratori, secondo i principi generali indicati nella presente legge. ((4)) L'esercizio della delega deve uniformarsi ai seguenti criteri direttivi: 1) assicurare l'unitarieta' degli obiettivi della sicurezza negli ambienti di lavoro e di vita, tenendo conto anche delle indicazioni della CEE e degli altri organismi internazionali riconosciuti; 2) prevedere l'emanazione di norme per assicurare il tempestivo e costante aggiornamento della normativa ai progressi tecnologici e alle conoscenze derivanti dalla esperienza diretta dei lavoratori; 3) prevedere l'istituzione di specifici corsi, anche obbligatori, di formazione antinfortunistica e prevenzionale; 4) prevedere la determinazione dei requisiti fisici e di eta' per attivita' e lavorazioni che presentino particolare rischio, nonche' le cautele alle quali occorre attenersi e le relative misure di controllo; 5) definire le procedure per il controllo delle condizioni ambientali, per gli accertamenti preventivi e periodici sullo stato di sicurezza nonche' di salute dei lavoratori esposti a rischio e per l'acquisizione delle informazioni epidemiologiche al fine di seguire sistematicamente l'evoluzione del rapporto salute-ambiente di lavoro; 6) stabilire: a) gli obblighi e le responsabilita' per la progettazione, la realizzazione, la vendita, il noleggio, la concessione in uso e l'impiego di macchine, componenti e parti di macchine, utensili, apparecchiature varie, attrezzatura di lavoro e di sicurezza, dispositivi di sicurezza, mezzi personali di protezione, apparecchiature, prodotti e mezzi protettivi per uso lavorativo ed extra lavorativo, anche domestico; b) i criteri e le modalita' per i collaudi e per le verifiche periodiche dei prodotti di cui alla precedente lettera a); 7) stabilire i requisiti ai quali devono corrispondere gli ambienti di lavoro al fine di consentirne l'agibilita', nonche' l'obbligo di notifica all'autorita' competente dei progetti di costruzione, di ampliamento, di trasformazione e di modifica di destinazione di impianti e di edifici destinati ad attivita' lavorative, per controllarne la rispondenza alle condizioni di sicurezza; 8) prevedere l'obbligo del datore di lavoro di programmare il processo produttivo in modo che esso risulti rispondente alle esigenze della sicurezza del lavoro, in particolare per quanto riguarda la dislocazione degli impianti e la determinazione dei rischi e dei mezzi per diminuirli; 9) stabilire le procedure di vigilanza allo scopo di garantire la osservanza delle disposizioni in materia di sicurezza del lavoro; 10) stabilire le precauzioni e le cautele da adottare per evitare l'inquinamento, sia interno che esterno, derivante da fattori di nocivita' chimici, fisici e biologici; 11) indicare i criteri e le modalita' per procedere, in presenza di rischio grave ed imminente, alla sospensione dell'attivita' in stabilimenti, cantieri o reparti o al divieto d'uso di impianti, macchine, utensili, apparecchiature varie, attrezzature e prodotti, sino alla eliminazione delle condizioni di nocivita' o di rischio accertate; 12) determinare le modalita' per la produzione, l'immissione sul mercato e l'impiego di sostanze e di prodotti pericolosi; 13) prevedere disposizioni particolari per settori lavorativi o per singole lavorazioni che comportino rischi specifici; 14) stabilire le modalita' per la determinazione e per l'aggiornamento dei valori-limite dei fattori di nocivita' di origine chimica, fisica e biologica di cui all'ultimo comma dell'articolo 4, anche in relazione alla localizzazione degli impianti; 15) prevedere le norme transitorie per conseguire condizioni di sicurezza negli ambienti di lavoro esistenti e le provvidenze da adottare nei confronti delle piccole e medie aziende per facilitare l'adeguamento degli impianti ai requisiti di sicurezza e di igiene previsti dal testo unico; 16) prevedere il riordinamento degli uffici e servizi della pubblica amministrazione preposti all'esercizio delle funzioni riservate allo Stato in materia di sicurezza del lavoro; 17) garantire il necessario coordinamento fra le funzioni esercitate dallo Stato e quelle esercitate nella materia dalle regioni e dai comuni, al fine di assicurare unita' di indirizzi ed omogeneita' di comportamenti in tutto il territorio nazionale nell'applicazione delle disposizioni in materia di sicurezza del lavoro; 18) definire per quanto concerne le omologazioni: a) i criteri direttivi, le modalita' e le forme per l'omologazione dei prototipi di serie e degli esemplari unici non di serie dei prodotti di cui al precedente numero 6), lettera a), sulla base di specifiche tecniche predeterminate, al fine di garantire le necessarie caratteristiche di sicurezza; b) i requisiti costruttivi dei prodotti da omologare; c) le procedure e le metodologie per i controlli di conformita' dei prodotti al tipo omologato. Le norme delegate determinano le sanzioni per i casi di inosservanza delle disposizioni contenute nel testo unico, da graduare in relazione alla gravita' delle violazioni e comportanti comunque, nei casi piu' gravi, l'arresto fino a sei mesi e l'ammenda fino a lire 10 milioni. Sono escluse dalla delega le norme in materia di prevenzione contro gli infortuni relative: all'esercizio di servizi ed impianti gestiti dalle ferrovie dello Stato, all'esercizio di servizi ed impianti gestiti dal Ministero delle poste e delle telecomunicazioni, all'esercizio dei trasporti terrestri pubblici e all'esercizio della navigazione marittima, aerea ed interna; nonche' le norme in materia di igiene del lavoro relative al lavoro a bordo delle navi mercantili e degli aeromobili.

--------------- AGGIORNAMENTO (4) La L. 29 febbraio 1980, n. 33, ha disposto (con l'art. 2, comma 2) che "La delega conferita al Governo con l'articolo 2 della legge 23 dicembre 1978, n. 833, scaduta il 31 dicembre 1979, e' rinnovata sino al 31 dicembre 1980."

### Art. 25. - (Prestazioni di cura)

Le prestazioni curative comprendono la assistenza medico-generica, specialistica, infermieristica, ospedaliera e farmaceutica. Le prestazioni medico-generiche, pediatriche, specialistiche e infermieristiche vengono erogate sia in forma ambulatoriale che domiciliare. L'assistenza medico-generica e pediatrica e' prestata dal personale dipendente o convenzionato del servizio sanitario nazionale operante nelle unita' sanitarie locali o nel comune di residenza del cittadino. La scelta del medico di fiducia deve avvenire fra i sanitari di cui al comma precedente. Il rapporto fiduciario puo' cessare in ogni momento a richiesta dell'assistito o del medico; in quest'ultimo caso la richiesta deve essere motivata. Le prestazioni medico-specialistiche, ivi comprese quelle di diagnostica strumentale e di laboratorio, sono fornite, di norma, presso gli ambulatori e i presidi delle unita' sanitarie locali di cui l'utente fa parte, ivi compresi gli istituti di cui agli articoli 39, 41 e 42 della presente legge. Le stesse prestazioni possono essere fornite da gabinetti specialistici, da ambulatori e da presidi convenzionati ai sensi della presente legge. L'utente puo' accedere agli ambulatori e strutture convenzionati per le prestazioni di diagnostica strumentale e di laboratorio per le quali, nel termine di tre giorni, le strutture pubbliche non siano in grado di soddisfare la richiesta di accesso alle prestazioni stesse. In tal caso l'unita' sanitaria locale rilascia immediatamente l'autorizzazione con apposita annotazione sulla richiesta stessa. ((L'autorizzazione non e' dovuta per le prescrizioni, relative a prestazioni il cui costo, in base alla normativa vigente, e' a totale carico dell'assistito)). Nei casi di richiesta urgente motivata da parte del medico in relazione a particolari condizioni di salute del paziente, il mancato immediato soddisfacimento della richiesta presso le strutture pubbliche di cui al sesto comma equivale ad autorizzazione ad accedere agli ambulatori o strutture convenzionati. In tal caso l'unita' sanitaria locale appone sulla richiesta la relativa annotazione. Le unita' sanitarie locali attuano misure idonee a garantire che le prestazioni urgenti siano erogate con priorita' nell'ambito delle loro strutture. Le prestazioni specialistiche possono essere erogate anche al domicilio dell'utente in forme che consentano la riduzione dei ricoveri ospedalieri. I presidi di diagnostica strumentale e di laboratorio devono rispondere ai requisiti minimi di strutturazione, dotazione strumentale e qualificazione funzionale del personale, aventi caratteristiche uniformi per tutto il territorio nazionale secondo uno schema tipo emanato ai sensi del primo comma dell'art. 5 della presente legge. L'assistenza ospedaliera e' prestata di norma attraverso gli ospedali pubblici e gli altri istituti convenzionati esistenti nel territorio della regione di residenza dell'utente. Nell'osservanza del principio della libera scelta del cittadino al ricovero presso gli ospedali pubblici e gli altri istituti convenzionati, la legge regionale, in rapporto ai criteri di programmazione stabiliti nel piano sanitario nazionale, disciplina i casi in cui e' ammesso il ricovero in ospedali pubblici, in istituti convenzionati o in strutture ospedaliere ad alta specializzazione ubicate fuori del proprio territorio, nonche' i casi nei quali potranno essere consentite forme straordinarie di assistenza indiretta.

### Art. 26. - (Prestazioni di riabilitazione)

Le prestazioni sanitarie dirette al recupero funzionale e sociale dei soggetti affetti da minorazioni fisiche, psichiche o sensoriali, dipendenti da qualunque causa, sono erogate dalle unita' sanitarie locali attraverso i propri servizi. L'unita' sanitaria locale, quando non sia in grado di fornire il servizio direttamente, vi provvede mediante convenzioni con istituti esistenti nella regione in cui abita l'utente o anche in altre regioni, aventi i requisiti indicati dalla legge, stipulate in conformita' ad uno schema tipo approvato dal Ministro della sanita', sentito il Consiglio sanitario nazionale. Sono altresi' garantite le prestazioni protesiche nei limiti e nelle forme stabilite con le modalita' di cui al secondo comma dell'articolo 3. Con decreto del Ministro della sanita', sentito il Consiglio sanitario nazionale, sono approvati un nomenclatore-tariffario delle protesi ed i criteri per la sua revisione periodica.

### Art. 27. - (Strumenti informativi)

Le unita' sanitarie locali forniscono gratuitamente i cittadini di un libretto sanitario personale. Il libretto sanitario riporta i dati caratteristici principali sulla salute dell'assistito esclusi i provvedimenti relativi a trattamenti sanitari obbligatori di cui al successivo articolo 33. L'unita' sanitaria locale provvede alla compilazione ed all'aggiornamento del libretto sanitario personale, i cui dati sono rigorosamente coperti dal segreto professionale. Tali dati conservano valore ai fini dell'anamnesi richiesta dalla visita di leva. Nel libretto sanitario sono riportati, a cura della sanita' militare, gli accertamenti e le cure praticate durante il servizio di leva. Il libretto e' custodito dall'interessato o da chi esercita la potesta' o la tutela e puo' essere richiesto solo dal medico, nell'esclusivo interesse della protezione della salute dell'intestatario. Con decreto dei Ministro della sanita', sentito il Consiglio sanitario nazionale ((e il Garante per la protezione dei dati personali)), e' approvato il modello del libretto sanitario personale comprendente le indicazioni relative all'eventuale esposizione a rischi in relazione alle condizioni di vita e di lavoro. Con lo stesso provvedimento sono determinate le modalita' per la graduale distribuzione a tutti i cittadini del libretto sanitario, a partire dai nuovi nati. Con decreto del Ministro della sanita', sentiti il Consiglio sanitario nazionale ((e il Garante per la protezione dei dati personali)), le organizzazioni sindacali dei lavoratori dipendenti ed autonomi maggiormente rappresentative e le associazioni dei datori di lavoro, vengono stabiliti i criteri in base ai quali, con le modalita' di adozione e di gestione previste dalla contrattazione collettiva, saranno costituiti i registri dei dati ambientali e biostatistici, allo scopo di pervenire a modelli uniformi per tutto il territorio nazionale. I dati complessivi derivanti dai suindicati strumenti informativi, facendo comunque salvo il segreto professionale, vengono utilizzati a scopo epidemiologico dall'Istituto superiore di sanita' oltre che per l'aggiornamento ed il miglioramento dell'attivita' sanitaria da parte delle unita' sanitarie locali, delle regioni e del Ministero della sanita'.

### Art. 28. - (Assistenza farmaceutica)

L'unita' sanitaria locale eroga l'assistenza farmaceutica attraverso le farmacie di cui sono titolari enti pubblici e le farmacie di cui sono titolari i privati, tutte convenzionate secondo i criteri e le modalita' di cui agli articoli 43 e 48. Gli assistiti possono ottenere dalle farmacie di cui al precedente comma, su presentazione di ricetta compilata dal medico curante, la fornitura di preparati galenici e di specialita' medicinali compresi nel prontuario terapeutico del servizio sanitario nazionale. L'unita' sanitaria locale, i suoi presidi e servizi, compresi quelli di cui all'articolo 18, e gli istituti ed enti convenzionati di cui ai successivi articoli 41, 42, 43, possono acquistare direttamente le preparazioni farmaceutiche di cui al secondo comma per la distribuzione agli assistiti nelle farmacie di cui sono titolari enti pubblici e per l'impiego negli ospedali, negli ambulatori e in tutti gli altri presidi sanitari. La legge regionale disciplina l'acquisto di detti medicinali e del restante materiale sanitario da parte delle unita' sanitarie locali e dei loro presidi e servizi, nonche' il coordinamento dell'attivita' delle farmacie comunali con i servizi dell'unita' sanitaria locale.

### Art. 29. - (Disciplina dei farmaci)

La produzione e la distribuzione dei farmaci devono essere regolate secondo criteri coerenti con gli obiettivi del servizio sanitario nazionale, con la funzione sociale del farmaco e con la prevalente finalita' pubblica della produzione. Con legge dello Stato sono dettate norme: a) per la disciplina dell'autorizzazione alla produzione e alla immissione in commercio dei farmaci, per i controlli di qualita' e per indirizzare la produzione farmaceutica alle finalita' del servizio sanitario nazionale; b) per la revisione programmata delle autorizzazioni gia' concesse per le specialita' medicinali in armonia con le norme a tal fine previste dalle direttive della Comunita' economica europea; c) per la disciplina dei prezzi dei farmaci, mediante una corretta metodologia per la valutazione dei costi; d) per la individuazione dei presidi autorizzati e per la definizione delle modalita' della sperimentazione clinica precedente l'autorizzazione alla immissione in commercio; e) per la brevettabilita' dei farmaci; f) per definire le caratteristiche e disciplinare la immissione in commercio dei farmaci da banco; g) per la regolamentazione del servizio di informazione scientifica sui farmaci e dell'attivita' degli informatori scientifici; h) per la revisione e la pubblicazione periodica della farmacopea ufficiale della Repubblica italiana, in armonia con le norme previste dalla farmacopea europea di cui alla legge del 22 ottobre 1973, n. 752.

### Art. 30. - (Prontuario farmaceutico)

Il Ministro della sanita', sentito il Consiglio sanitario nazionale, approva con proprio decreto il prontuario terapeutico del servizio sanitario nazionale, previa proposta di un comitato composto: dal Ministro della sanita' che lo presiede; dal direttore generale del servizio farmaceutico del Ministero della sanita'; dal direttore dell'Istituto superiore di sanita'; dai direttori dei laboratori di farmacologia e di chimica del farmaco dell'istituto superiore di sanita'; da sette esperti designati dal Ministro della sanita', scelti fra docenti universitari di farmacologia, di chimica farmaceutica o materie affini, di patologia o clinica medica e fra medici e farmacisti dipendenti o convenzionati con le strutture del servizio sanitario nazionale; da un rappresentante del Ministero dell'industria, commercio e artigianato; da due esperti di economia sanitaria designati dal Ministro della sanita', su proposta del Consiglio nazionale delle ricerche; da cinque esperti della materia designati dalle regioni. Essi vengono scelti dal Presidente del Consiglio dei ministri tra gli esperti designati uno ciascuno dalle regioni, e per quanto concerne la regione Trentino Alto Adige, uno dalla provincia di Trento e uno dalla provincia di Bolzano. Il comitato di cui al precedente comma e' nominato con decreto del Presidente del Consiglio dei ministri, su proposta del Ministro della sanita', ed e' rinnovato ogni tre anni. Il prontuario terapeutico del servizio sanitario nazionale deve uniformarsi ai principi dell'efficacia terapeutica, della economicita' del prodotto, della semplicita' e chiarezza nella classificazione e dell'esclusione dei prodotti da banco. Il Ministro della sanita' provvede entro il 31 dicembre di ogni anno ad aggiornare il prontuario terapeutico con la procedura di cui al primo comma. Fino all'approvazione del prontuario terapeutico del servizio sanitario nazionale di cui al presente articolo, resta in vigore il prontuario di cui all'articolo 9 del decreto-legge 8 luglio 1974, n. 264, convertito, con modificazioni, nella legge 17 agosto 1974, n. 386. ((24))

--------------- AGGIORNAMENTO (24) La L. 24 dicembre 1993, n. 537, ha disposto (con l'art. 8, comma 9) che: "A decorrere dal 1 gennaio 1994, e' abolito il prontuario terapeutico del Servizio sanitario nazionale di cui all'articolo 30 della legge 23 dicembre 1978, n. 833. A decorrere dalla medesima data, le specialita' medicinali ed i prodotti galenici per i quali sia stata rilasciata l'autorizzazione sono erogabili dal Servizio sanitario nazionale".

### Art. 31. - (Pubblicita' ed informazione scientifica sui farmaci)

Al servizio sanitario nazionale spettano compiti di informazione scientifica sui farmaci e di controllo sull'attivita' di informazione scientifica delle imprese titolari delle autorizzazioni alla immissione in commercio di farmaci. E' vietata ogni forma di propaganda e di pubblicita' presso il pubblico dei farmaci sottoposti all'obbligo della presentazione di ricetta medica e comunque di quelli contenuti nel prontuario terapeutico approvato ai sensi dell'articolo 30. Sino all'entrata in vigore della nuova disciplina generale dei farmaci di cui all'articolo 29, il Ministro della sanita' determina con proprio decreto i limiti e le modalita' per la propaganda e la pubblicita' presso il pubblico dei farmaci diversi da quelli indicati nel precedente comma, tenuto conto degli obiettivi di educazione sanitaria di cui al comma successivo e delle direttive in materia della Comunita' economica europea. Il Ministro della sanita', sentito il Consiglio sanitario nazionale, viste le proposte delle regioni, tenuto conto delle direttive comunitarie e valutate le osservazioni e proposte che perverranno dall'Istituto superiore di sanita' e dagli istituti universitari e di ricerca, nonche' dall'industria farmaceutica, predispone un programma pluriennale per l'informazione scientifica sui farmaci, finalizzato anche ad iniziative di educazione sanitaria e detta norma per la regolamentazione del predetto servizio e dell'attivita' degli informatori scientifici. Nell'ambito del programma di cui al precedente comma, le unita' sanitarie locali e le imprese di cui al primo comma, nel rispetto delle proprie competenze, svolgono informazione scientifica sotto il controllo del Ministero della sanita'. Il programma per l'informazione scientifica deve, altresi', prevedere i limiti e le modalita' per la fornitura ai medici chirurghi di campioni gratuiti di farmaci.

### Art. 32. - (Funzioni di igiene e sanita' pubblica e di polizia veterinaria)

Il Ministro della sanita' puo' emettere ordinanze di carattere contingibile e urgente, in materia di igiene e sanita' pubblica e di polizia veterinaria, con efficacia estesa all'intero territorio nazionale o a parte di esso comprendente piu' regioni. La legge regionale stabilisce norme per l'esercizio delle funzioni in materia di igiene e sanita' pubblica, di vigilanza sulle farmacie e di polizia veterinaria, ivi comprese quelle gia' esercitate dagli uffici del medico provinciale e del veterinario provinciale e dagli ufficiali sanitari e veterinari comunali o consortili, e disciplina il trasferimento dei beni e del personale relativi. Nelle medesime materie sono emesse dal presidente della giunta regionale o dal sindaco ordinanze di carattere contingibile ed urgente, con efficacia estesa rispettivamente alla regione o a parte del suo territorio comprendente piu' comuni e al territorio comunale. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)). Sono altresi' fatti salvi i poteri degli organi dello Stato preposti in base alle leggi vigenti alla tutela dell'ordine pubblico.

### Art. 33. - (Norme per gli accertamenti ed i trattamenti sanitari volontari e obbligatori)

Gli accertamenti ed i trattamenti sanitari sono di norma volontari. Nei casi di cui alla presente legge e in quelli espressamente previsti da leggi dello Stato possono essere disposti dall'autorita' sanitaria accertamenti e trattamenti sanitari obbligatori, secondo l'articolo 32 della Costituzione, nel rispetto della dignita' della persona e dei diritti civili e politici, compreso per quanto possibile il diritto alla libera scelta del medico e del luogo di cura. Gli accertamenti ed i trattamenti sanitari obbligatori sono disposti con provvedimento del sindaco nella sua qualita' di autorita' sanitaria, su proposta motivata di un medico. Gli accertamenti e i trattamenti sanitari obbligatori sono attuati dai presidi e servizi sanitari pubblici territoriali e, ove necessiti la degenza, nelle strutture ospedaliere pubbliche o convenzionate. Gli accertamenti e i trattamenti sanitari obbligatori di cui ai precedenti commi devono essere accompagnati da iniziative rivolte ad assicurare il consenso e la partecipazione da parte di chi vi e' obbligato. L'unita' sanitaria locale opera per ridurre il ricorso ai suddetti trattamenti sanitari obbligatori, sviluppando le iniziative di prevenzione e di educazione sanitaria ed i rapporti organici tra servizi e comunita'. Nel corso del trattamento sanitario obbligatorio, l'infermo ha diritto di comunicare con chi ritenga opportuno. Chiunque puo' rivolgere al sindaco richiesta di revoca o di modifica del provvedimento con il quale e' stato disposto o prolungato il trattamento sanitario obbligatorio. Sulle richieste di revoca o di modifica il sindaco decide entro dieci giorni. I provvedimenti di revoca o di modifica sono adottati con lo stesso procedimento del provvedimento revocato o modificato.

### Art. 34. - (Accertamenti e trattamenti sanitari volontari e obbligatori per malattia mentale)

La legge regionale, nell'ambito della unita' sanitaria locale e nel complesso dei servizi generali per la tutela della salute, disciplina l'istituzione di servizi a struttura dipartimentale che svolgono funzioni preventive, curative e riabilitative relative alla salute mentale. Le misure di cui al secondo comma dell'articolo precedente possono essere disposte nei confronti di persone affette da malattia mentale. Gli interventi di prevenzione, cura e riabilitazione relativi alle malattie mentali sono attuati di norma dai servizi e presidi territoriali extraospedalieri di cui al primo comma. Il trattamento sanitario obbligatorio per malattia mentale puo' prevedere che le cure vengano prestate in condizioni di degenza ospedaliera solo se esistano alterazioni psichiche tali da richiedere urgenti interventi terapeutici, se gli stessi non vengano accettati dall'infermo e se non vi siano le condizioni e le circostanze che consentano di adottare tempestive ed idonee misure sanitarie extraospedaliere. Il provvedimento che dispone il trattamento sanitario obbligatorio in condizioni di degenza ospedaliera deve essere preceduto dalla convalida della proposta di cui al terzo comma dell'articolo 33 da parte di un medico della unita' sanitaria locale e deve essere motivato in relazione a quanto previsto nel presente comma. Nei casi di cui al precedente comma il ricovero deve essere attuato presso gli ospedali generali, in specifici servizi psichiatrici di diagnosi e cura all'interno delle strutture dipartimentali per la salute mentale comprendenti anche i presidi e i servizi extraospedalieri, al fine di garantire la continuita' terapeutica. I servizi ospedalieri di cui al presente comma sono dotati di posti letto nel numero fissato dal piano sanitario regionale.

### Art. 35. - (Procedimento relativo agli accertamenti e trattamenti sanitari obbligatori in condizioni di degenza ospedaliera per malattia mentale e tutela giurisdizionale)

Il provvedimento con il quale il sindaco dispone il trattamento sanitario obbligatorio in condizioni di degenza ospedaliera, da emanarsi entro 48 ore dalla convalida di cui all'articolo 34, quarto comma, corredato dalla proposta medica motivata di cui all'articolo 33, terzo comma, e dalla suddetta convalida deve essere notificato, entro 48 ore dal ricovero, tramite messo comunale, al giudice tutelare nella cui circoscrizione rientra il comune. ((29)) Il giudice tutelare, entro le successive 48 ore, assunte le informazioni e disposti gli eventuali accertamenti, provvede con decreto motivato a convalidare o non convalidare il provvedimento e ne da' comunicazione al sindaco. In caso di mancata convalida il sindaco dispone la cessazione del trattamento sanitario obbligatorio in condizioni di degenza ospedaliera. ((29)) Se il provvedimento di cui al primo comma del presente articolo e' disposto dal sindaco di un comune diverso da quello di residenza dell'infermo, ne va data comunicazione al sindaco di questo ultimo comune, nonche' al giudice tutelare nella cui circoscrizione rientra il comune di residenza. Se il provvedimento di cui al primo comma del presente articolo e' adottato nei confronti di cittadini stranieri o di apolidi, ne va data comunicazione al Ministero dell'interno, e al consolato competente, tramite il prefetto. Nei casi in cui il trattamento sanitario obbligatorio debba protrarsi oltre il settimo giorno, ed in quelli di ulteriore prolungamento, il sanitario responsabile del servizio psichiatrico della unita sanitaria locale e' venuto a formulare, in tempo utile, una proposta motivata al sindaco che ha disposto il ricovero, il quale ne da' comunicazione al giudice tutelare, con le modalita' e per gli adempimenti di cui al primo e secondo comma del presente articolo, indicando la ulteriore durata presumibile del trattamento stesso. ((29)) Il sanitario di cui al comma precedente e' tenuto a comunicare al sindaco, sia in caso di dimissione del ricoverato che in continuita' di degenza, la cessazione delle condizioni che richiedono l'obbligo del trattamento sanitario; comunica altresi' la eventuale sopravvenuta impossibilita' a proseguire il trattamento stesso. Il sindaco, entro 48 ore dal ricevimento della comunicazione del sanitario, ne da' notizia al giudice tutelare. Qualora ne sussista la necessita' il giudice tutelare adotta i provvedimenti urgenti che possono occorrere per conservare e per amministrare il patrimonio dell'infermo. La omissione delle comunicazioni di cui al primo, quarto e quinto comma del presente articolo determina la cessazione di ogni effetto del provvedimento e configura, salvo che non sussistano gli estremi di un delitto piu' grave, il reato di omissione di atti di ufficio. Chi e' sottoposto a trattamento sanitario obbligatorio, e chiunque vi abbia interesse, puo' proporre al tribunale competente per territorio ricorso contro il provvedimento convalidato dal giudice tutelare. Entro il termine di trenta giorni, decorrente dalla scadenza del termine di cui al secondo comma del presente articolo, il sindaco puo' proporre analogo ricorso avverso la mancata convalida del provvedimento che dispone il trattamento sanitario obbligatorio. Nel processo davanti al tribunale le parti possono stare in giudizio senza ministero di difensore e farsi rappresentare da persona munita di mandato scritto in calce al ricorso o in atto separato. Il ricorso puo' essere presentato al tribunale mediante raccomandata con avviso di ricevimento. Il presidente del tribunale fissa l'udienza di comparizione delle parti con decreto in calce al ricorso che, a cura del cancelliere, e' notificato alle parti nonche' al pubblico ministero. Il presidente del tribunale, acquisito il provvedimento che ha disposto il trattamento sanitario obbligatorio e sentito il pubblico ministero, puo' sospendere il trattamento medesimo anche prima che sia tenuta l'udienza di comparizione. Sulla richiesta di sospensiva il presidente del tribunale provvede entro dieci giorni. Il tribunale provvede in camera di consiglio, sentito il pubblico ministero, dopo avere assunto le informazioni e raccolto le prove disposte di ufficio o richieste dalle parti. I ricorsi ed i successivi procedimenti sono esenti da imposta di bollo. La decisione del processo non e' soggetta a registrazione.

--------------- AGGIORNAMENTO (29) La Corte Costituzionale, con sentenza 5 - 30 maggio 2025, n. 76 (in G.U. 1ª s.s. 04/06/2025, n. 23), ha dichiarato "l'illegittimita' costituzionale dell'art. 35 della legge 23 dicembre 1978, n. 833 (Istituzione del servizio sanitario nazionale): - nella parte in cui non prevede, al primo comma, dopo le parole «deve essere», le parole «comunicato alla persona interessata o al suo legale rappresentante, ove esistente, e»; - nella parte in cui non prevede, al secondo comma, dopo le parole «assunte le informazioni», le parole «, sentita la persona interessata»; - nella parte in cui non prevede, al secondo comma, dopo le parole «ne da' comunicazione al sindaco», le parole «e ne dispone la notificazione alla persona interessata o al suo legale rappresentante, ove esistente»". In via consequenziale, ai sensi dell'art. 27 della legge 11 marzo 1953, n. 87 (Norme sulla costituzione e sul funzionamento della Corte costituzionale), ha dichiarato "l'illegittimita' costituzionale dell'art. 35 della legge n. 833 del 1978 nella parte in cui non prevede, al quarto comma, dopo le parole «ne da' comunicazione», le parole «alla persona interessata o al suo legale rappresentante, ove esistente, e»".

### Art. 36. - (Termalismo terapeutico)

Le prestazioni idrotermali, limitate al solo aspetto terapeutico, da erogarsi presso gli appositi presidi e servizi di cui al presente articolo, nonche' presso aziende termali di enti pubblici e privati, riconosciute ai sensi dell'articolo 6, lettera t), e convenzionate ai sensi dell'articolo 44, sono garantite nei limiti previsti dal piano sanitario nazionale di cui all'articolo 53 e nelle forme stabilite con le modalita' di cui al secondo comma dell'articolo 3. La legge regionale promuove la integrazione e la qualificazione sanitaria degli stabilimenti termali pubblici, in particolare nel settore della riabilitazione, e favorisce altresi' la valorizzazione sotto il profilo sanitario delle altre aziende termali. ((COMMA ABROGATO DALLA L. 31 DICEMBRE 1991, N. 412)) Le aziende termali gia' facenti capo all'EAGAT e che saranno assegnate alle regioni, per l'ulteriore destinazione agli enti locali, in base alla procedura prevista dall'articolo 113 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616, e dall'articolo 1-quinquies della legge 21 ottobre 1978, n. 641, sono dichiarate presidi e servizi multizonali delle unita' sanitarie locali nel cui territorio sono ubicate. La destinazione agli enti locali delle attivita', patrimoni, pertinenze e personale delle suddette aziende dovra' avvenire entro il 31 dicembre 1979, adottando, in quanto applicabili, le disposizioni di cui ai successivi articoli 65 e 67.

### Art. 37. - (Delega per la disciplina dell'assistenza sanitaria agli italiani all'estero, ai cittadini del comune di Campione d'Italia ed al personale navigante)

Il Governo e' delegato ad emanare, entro il 31 dicembre 1979, su proposta del Ministro della sanita', di concerto con i Ministri degli affari esteri, del lavoro e della previdenza sociale, uno o piu' decreti aventi valore di legge ordinaria per disciplinare l'erogazione dell'assistenza sanitaria ai cittadini italiani all'estero, secondo i principi generali della presente legge e con l'osservanza dei seguenti criteri direttivi: a) dovra' essere assicurata attraverso forme di assistenza diretta o indiretta, la tutela della salute dei lavoratori e dei loro familiari aventi diritto, ivi compresi, per i casi d'urgenza, i lavoratori frontalieri, per tutto il periodo di permanenza all'estero connesso alla prestazione di attivita' lavorativa, qualora tali soggetti non godano di prestazioni assistenziali garantite da leggi locali o tali prestazioni siano palesemente inferiori ai livelli di prestazioni sanitarie stabiliti con le modalita' di cui al secondo comma dell'articolo 3; b) dovranno essere previste particolari forme e procedure, anche attraverso convenzioni dirette, per l'erogazione dell'assistenza ai dipendenti dello Stato e di enti pubblici, ai loro familiari aventi diritto, nonche' ai contrattisti stranieri, che prestino la loro opera presso rappresentanze diplomatiche, uffici consolari, istituzioni scolastiche e culturali ovvero in delegazioni o uffici di enti pubblici oppure in servizio di assistenza tecnica; c) dovranno essere previste specifiche norme per disciplinare l'assistenza sanitaria ai cittadini italiani residenti nel comune di Campione d'Italia per gli interventi che, pur compresi fra quelli previsti dal secondo comma dell'articolo 3, non possono essere erogati dall'unita' sanitaria locale di cui fa parte il comune, a causa della sua eccezionale collocazione geografica. Restano salve le norme che disciplinano l'assistenza sanitaria dovuta alle persone aventi diritto all'assistenza stessa in virtu' di trattati e accordi internazionali bilaterali o multilaterali di reciprocita' sottoscritti dall'Italia, nonche' in attuazione della legge 2 maggio 1969, n. 302. Entro il termine di cui al primo comma il Governo e' delegato ad emanare, su proposta del Ministro della sanita', di concerto con i Ministri della marina mercantile, dei trasporti, degli affari esteri, un decreto avente valore di legge ordinaria per disciplinare l'erogazione dell'assistenza sanitaria al personale navigante, marittimo e dell'aviazione civile, secondo i principi generali e con l'osservanza dei criteri direttivi indicati nella presente legge, tenuto conto delle condizioni specifiche di detto personale. ((4))

--------------- AGGIORNAMENTO (4) La L. 29 febbraio 1980, n. 33, ha disposto (con l'art. 2, comma 1) che: "Le deleghe conferite al Governo con gli articoli 7, 42 e 70 della legge 23 dicembre 1978, n. 833, scadute il 23 dicembre 1979, nonche' le deleghe conferite con gli articoli 23 e 37 della legge medesima, scadute il 31 dicembre 1979, sono rinnovate fino al 31 luglio 1980".

### Art. 38. - (Servizio di assistenza religiosa)

Presso le strutture di ricovero del servizio sanitario nazionale e' assicurata l'assistenza religiosa nel rispetto della volonta' e della liberta' di coscienza del cittadino. A tale fine l'unita' sanitaria locale provvede per l'ordinamento del servizio di assistenza religiosa cattolica d'intesa con gli ordinari diocesani competenti per territorio; per gli altri culti d'intesa con le rispettive autorita' religiose competenti per territorio.

### Art. 39. - (Cliniche universitarie e relative convenzioni)

Fino alla riforma dell'ordinamento universitario e della facolta' di medicina, per i rapporti tra regioni ed universita' relativamente alle attivita' del servizio sanitario nazionale, si applicano le disposizioni di cui ai successivi commi. Al fine di realizzare un idoneo coordinamento delle rispettive funzioni istituzionali, le regioni e l'universita' stipulano convenzioni per disciplinare, anche sotto l'aspetto finanziario: 1) l'apporto nel settore assistenziale delle facolta' di medicina alla realizzazione degli obiettivi della programmazione sanitaria regionale; 2) l'utilizzazione da parte delle facolta' di medicina, per esigenze di ricerca e di insegnamento, di idonee strutture delle unita' sanitarie locali e l'apporto di queste ultime ai compiti didattici e di ricerca della universita'. Tali convenzioni una volta definite fanno parte dei piani sanitari regionali di cui al terzo comma dell'articolo 11. Con tali convenzioni: a) saranno indicate le strutture delle unita' sanitarie locali da utilizzare a fini didattici e di ricerca, in quanto rispondano ai requisiti di idoneita' fissati con decreto interministeriale adottato di concerto tra i Ministri della pubblica istruzione e della sanita'; b) al fine di assicurare il miglior funzionamento dell'attivita' didattica e di ricerca mediante la completa utilizzazione del personale docente delle facolta' di medicina e l'apporto all'insegnamento di personale ospedaliero laureato e di altro personale laureato e qualificato sul piano didattico, saranno indicate le strutture a direzione universitaria e quelle a direzione ospedaliera alle quali affidare funzioni didattiche integrative di quelle universitarie. Le strutture a direzione ospedaliera cui vengono affidate le suddette funzioni didattiche non possono superare il numero di quelle a direzione universitaria. Le indicazioni previste nelle lettere a) e b) del precedente comma sono formulate previo parere espresso da una commissione di esperti composta da tre rappresentanti della universita' e tre rappresentanti della regione. Le convenzioni devono altresi' prevedere: 1) che le cliniche e gli istituti universitari di ricovero e cura che sono attualmente gestiti direttamente dall'universita', fermo restando il loro autonomo ordinamento, rientrino, per quanto concerne l'attivita' di assistenza sanitaria, nei piani sanitari nazionali e regionali; 2) che l'istituzione di nuove divisioni, sezioni e servizi per sopravvenute esigenze didattiche e di ricerca che comportino nuovi oneri connessi all'assistenza a carico delle regioni debba essere attuata d'intesa tra regioni ed universita'. In caso di mancato accordo tra regioni ed universita' in ordine alla stipula della convenzione o in ordine alla istituzione di nuove divisioni, sezioni e servizi di cui al comma precedente si applica la procedura di cui all'articolo 50 della legge 12 febbraio 1968, n. 132, sentiti il Consiglio sanitario nazionale e la sezione del Consiglio superiore della pubblica istruzione. Le convenzioni di cui al secondo comma vanno attuate, per quanto concerne la utilizzazione delle strutture assistenziali delle unita' sanitarie locali, con specifiche convenzioni, da stipulare tra l'universita' e l'unita' sanitaria locale, che disciplineranno sulla base della legislazione vigente le materie indicate nell'articolo 4 del decreto del Presidente della Repubblica 27 marzo 1969, n. 129. Le convenzioni previste nel presente articolo sono stipulate sulla base di schemi tipo da emanare entro sei mesi dall'entrata in vigore della presente legge, approvati di concerto tra i Ministri della pubblica istruzione e della sanita', sentite le regioni, il Consiglio sanitario nazionale e la 1ª sezione del Consiglio superiore della pubblica istruzione.

### Art. 40. - (Enti di ricerca e relative convenzioni)

Convenzioni analoghe a quelle previste per le cliniche universitarie, e di cui all'articolo 39 della presente legge, potranno essere stipulate tra le regioni e gli enti di ricerca i cui organi svolgano attivita' finalizzata agli obiettivi del servizio sanitario nazionale, al fine di disciplinare la erogazione da parte di tali organi di prestazioni sanitarie a livello preventivo, assistenziale e riabilitativo, nonche' la utilizzazione del personale degli enti di ricerca secondo i fini della presente legge.

### Art. 41. - (Convenzioni con istituzioni sanitarie riconosciute che erogano assistenza pubblica)

Salva la vigilanza tecnico-sanitaria spettante all'unita' sanitaria locale competente per territorio, nulla e' innovato alle disposizioni vigenti per quanto concerne il regime giuridico-amministrativo degli istituti ed enti ecclesiastici civilmente riconosciuti che esercitano l'assistenza ospedaliera, nonche' degli ospedali di cui all'articolo 1 della legge 26 novembre 1973, n. 817. Salva la vigilanza tecnico-sanitaria spettante all'unita' sanitaria locale competente per territorio, nulla e' innovato alla disciplina vigente per quanto concerne l'ospedale Galliera di Genova. Con legge dello Stato, entro il 31 dicembre 1979, si provvede al nuovo ordinamento dell'Ordine mauriziano, ai sensi della XIV Disposizione transitoria e finale della Costituzione ed in conformita', sentite le regioni interessate, per quanto attiene all'assistenza ospedaliera, ai principi di cui alla presente legge. I rapporti delle unita' sanitarie locali competenti per territorio con gli istituti, enti ed ospedali di cui al primo comma che abbiano ottenuto la classificazione ai sensi della legge 12 febbraio 1968, n. 132, nonche' con l'ospedale Galliera di Genova e con il Sovrano Ordine militare di Malta, sono regolati da apposite convenzioni. Le convenzioni di cui al terzo comma del presente articolo devono essere stipulate in conformita' a schemi tipo approvati dal Consiglio dei ministri, su proposta del Ministro della sanita', sentito il Consiglio sanitario nazionale. Le regioni, nell'assicurare la dotazione finanziaria alle unita' sanitarie locali, devono tener conto delle convenzioni di cui al presente articolo.

### Art. 42. - (Istituti di ricovero e di cura a carattere scientifico)

Le disposizioni del presente articolo si applicano agli istituti che insieme a prestazioni sanitarie di ricovero e cura svolgono specifiche attivita' di ricerca scientifica biomedica. Il riconoscimento del carattere scientifico di detti istituti e' effettuato con decreto del Ministro della sanita' di intesa con il Ministro della pubblica istruzione, sentite le regioni interessate e il Consiglio sanitario nazionale. Detti istituti per la parte assistenziale sono considerati presidi ospedalieri multizonali delle unita' sanitarie locali nel cui territorio sono ubicati. Nei confronti di detti istituti, per la parte assistenziale, spettano alle regioni le funzioni che esse esercitano nei confronti dei presidi ospedalieri delle unita' sanitarie locali o delle case di cura private a seconda che si tratti di istituti aventi personalita' giuridica di diritto pubblico o di istituti aventi personalita' giuridica di diritto privato. Continuano ad essere esercitate dai competenti organi dello Stato le funzioni attinenti al regime giuridico-amministrativo degli istituti. Per gli istituti aventi personalita' giuridica di diritto privato sono stipulate dalle regioni convenzioni per assistenza sanitaria, sulla base di schemi tipo approvati dal Consiglio dei ministri, su proposta del Ministro della sanita', sentito il Consiglio sanitario nazionale, che tengano conto della particolarita' di detti istituti. I rapporti tra detti istituti e le regioni sono regolati secondo quanto previsto dagli articoli 41, 43 e 44 della presente legge. Il controllo sulle deliberazioni degli istituti aventi personalita' giuridica di diritto pubblico, per quanto attiene alle attivita' assistenziali, e' esercitato nelle forme indicate dal primo comma dell'articolo 49. L'annullamento delle deliberazioni adottate in deroga alle disposizioni regionali non e' consentito ove la deroga sia stata autorizzata con specifico riguardo alle finalita' scientifiche dell'istituto, mediante decreto del Ministro della sanita' di concerto con il Ministro della ricerca scientifica. ((COMMA ABROGATO DAL D. LGS. 30 GIUGNO 1993, N. 269)) ((23)) ((COMMA ABROGATO DAL D. LGS. 30 GIUGNO 1993, N. 269)) ((23)) ((COMMA ABROGATO DAL D. LGS. 30 GIUGNO 1993, N. 269)) ((23)) ((COMMA ABROGATO DAL D. LGS. 30 GIUGNO 1993, N. 269)) (4) ((23))

--------------- AGGIORNAMENTO (4) La L. 29 febbraio 1980, n. 33, ha disposto (con l'art. 2, comma 1) che "Le deleghe conferite al Governo con gli articoli 7, 42 e 70 della legge 23 dicembre 1978, n. 833, scadute il 23 dicembre 1979, nonche' le deleghe conferite con gli articoli 23 e 37 della legge medesima, scadute il 31 dicembre 1979, sono rinnovate fino al 31 luglio 1980". --------------- AGGIORNAMENTO (23) Il D. Lgs. 30 giugno 1993, n. 269, ha disposto (con l'art. 8, comma 2) che l'abrogazione ha efficacia dalla entrata in vigore dei regolamenti previsti dal presente decreto, in relazione alle materie di rispettiva competenza.

### Art. 43. - (Autorizzazione e vigilanza su istituzioni sanitarie)

La legge regionale disciplina l'autorizzazione e la vigilanza sulle istituzioni sanitarie di carattere privato, ivi comprese quelle di cui all'articolo 41, primo comma, che non hanno richiesto di essere classificate ai sensi della legge 12 febbraio 1968, n. 132, su quelle convenzionate di cui all'articolo 26, e sulle aziende termali e definisce le caratteristiche funzionali cui tali istituzioni e aziende devono corrispondere onde assicurare livelli di prestazioni sanitarie non inferiori a quelle erogate dai corrispondenti presidi e servizi delle unita' sanitarie locali. Restano ferme le funzioni di indirizzo e coordinamento di cui all'articolo 5. Gli istituti, enti ed ospedali di cui all'articolo 41, primo comma, che non abbiano ottenuto la classificazione ai sensi della legge 12 febbraio 1968, n. 132, e alle istituzioni a carattere privato che abbiano un ordinamento dei servizi ospedalieri corrispondente a quello degli ospedali gestiti direttamente dalle unita' sanitarie locali, possono ottenere dalla regione, su domanda da presentarsi entro i termini stabiliti con legge regionale, che i loro ospedali, a seconda delle caratteristiche tecniche e specialistiche, siano considerati, ai fini dell'erogazione dell'assistenza sanitaria, presidi dell'unita' sanitaria locale nel cui territorio sono ubicati, sempre che il piano regionale sanitario preveda i detti presidi. I rapporti dei predetti istituti, enti ed ospedali con le unita' sanitarie locali sono regolati da apposite convenzioni. Le convenzioni di cui al comma precedente devono essere stipulate in conformita' a schemi tipo approvati dal Consiglio dei ministri, su proposta del Ministro della sanita', sentito il Consiglio sanitario nazionale e devono prevedere fra l'altro forme e modalita' per assicurare l'integrazione dei relativi presidi con quelli delle unita' sanitarie locali. Sino alla emanazione della legge regionale di cui al primo comma rimangono in vigore gli articoli 51, 52 e 53, primo e secondo comma, della legge 12 febbraio 1968, n. 132, e il decreto del Ministro della sanita' in data 5 agosto 1977, adottato ai sensi del predetto articolo 51 e pubblicato nella Gazzetta Ufficiale della Repubblica del 31 agosto 1977, n. 236, nonche' gli articoli 194, 195, 196, 197 e 198 del testo unico delle leggi sanitarie approvato con regio decreto 27 luglio 1934, n. 1265, intendendosi sostituiti al Ministero della sanita' la regione e al medico provinciale e al prefetto il presidente della giunta regionale.

### Art. 44. - (Convenzioni con istituzioni sanitarie)

Il piano sanitario regionale di cui all'articolo 55 accerta la necessita' di convenzionare le istituzioni private di cui all'articolo precedente, tenendo conto prioritariamente di quelle gia' convenzionate. La legge regionale stabilisce norme per: a) le convenzioni fra le unita' sanitarie locali e le istituzioni private di cui all'articolo precedente, da stipularsi in armonia col piano sanitario regionale e garantendo la erogazione di prestazioni sanitarie non inferiori a quelle erogate dai corrispondenti presidi e servizi delle unita' sanitarie locali; b) le convenzioni fra le unita' sanitarie locali e le aziende termali di cui all'articolo 36. Dette convenzioni sono stipulate dalle unita' sanitarie locali in conformita' a schemi tipo approvati dal Ministro della sanita', sentito il Consiglio sanitario nazionale. Le convenzioni stipulate a norma del presente articolo dalle unita' sanitarie locali competenti per territorio hanno efficacia anche per tutte le altre unita' sanitarie locali del territorio nazionale.

### Art. 45. - (Associazioni di volontariato)

E' riconosciuta la funzione delle associazioni di volontariato liberamente costituite aventi la finalita' di concorrere al conseguimento dei fini istituzionali del servizio sanitario nazionale. Tra le associazioni di volontariato di cui al comma precedente sono ricomprese anche le istituzioni a carattere associativo, le cui attivita' si fondano, a norma di statuto, su prestazioni volontarie e personali dei soci. Dette istituzioni, se attualmente riconosciute come istituzioni pubbliche di assistenza e beneficenza (IPAB), sono escluse dal trasferimento di cui all'articolo 25 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616. A tal fine le predette istituzioni avanzano documentata istanza al presidente della giunta regionale che con proprio decreto procede, sentito il consiglio comunale ove ha sede l'istituzione, a dichiarare l'esistenza delle condizioni previste nel comma precedente. >Di tale decreto viene data notizia alla commissione di cui al sesto comma dell'articolo 25 del decreto del Presidente della Repubblica 24 luglio 1977, n. 616. Sino all'entrata in vigore della legge di riforma dell'assistenza pubblica dette istituzioni restano disciplinate dalla legge 17 luglio 1890, n. 6972, e successive modifiche e integrazioni. I rapporti fra le unita' sanitarie locali e le associazioni del volontariato ai fini del loro concorso alle attivita' sanitarie pubbliche sono regolati da apposite convenzioni nell'ambito della programmazione e della legislazione sanitaria regionale.

### Art. 46. - (Mutualita' volontaria)

La mutualita' volontaria e' libera. E' vietato agli enti, imprese ed aziende pubbliche contribuire sotto qualsiasi forma al finanziamento di associazioni mutualistiche liberamente costituite aventi finalita' di erogare prestazioni integrative dell'assistenza sanitaria prestata dal servizio sanitario nazionale.

## PERSONALE.

### Art. 47. - (Personale dipendente)

Lo stato giuridico ed economico del personale delle unita' sanitarie locali e' disciplinato, salvo quanto previsto espressamente dal presente articolo, secondo i principi generali e comuni del rapporto di pubblico impiego. In relazione a quanto disposto dal secondo comma dell'articolo 13, la gestione amministrativa del personale delle unita' sanitarie locali e' demandata all'organo di gestione delle stesse, dal quale il suddetto personale dipende sotto il profilo funzionale, disciplinare e retributivo. Il Governo e' delegato ad emanare, entro il 30 giugno 1979, su proposta del Presidente del Consiglio, di concerto con i Ministri della sanita' e del lavoro e della previdenza sociale, previa consultazione delle associazioni sindacali delle categorie interessate uno o piu' decreti aventi valore di legge ordinaria per disciplinare, salvo quanto previsto dall'ottavo comma del presente articolo, lo stato giuridico del personale delle unita' sanitarie locali nel rispetto dei seguenti principi e criteri direttivi: 1) assicurare un unico ordinamento del personale in tutto il territorio nazionale; 2) disciplinare i ruoli del personale sanitario, professionale, tecnico ed amministrativo; 3) definire le tabelle di equiparazione per il personale proveniente dagli enti e dalle amministrazioni le cui funzioni sono trasferite ai comuni per essere esercitate mediante le unita' sanitarie locali e provvedere a regolare i trattamenti di previdenza e di quiescenza, compresi gli eventuali trattamenti integrativi di cui all'articolo 14 della legge 20 marzo 1975, n. 70; 4) garantire con criteri uniformi il diritto all'esercizio della libera attivita' professionale per i medici e veterinari dipendenti dalle unita' sanitarie locali, degli istituti universitari e dei policlinici convenzionati e degli istituti scientifici di ricovero e cura di cui all'articolo 42. Con legge regionale sono stabiliti le modalita' e i limiti per l'esercizio di tale attivita'; 5) prevedere misure rivolte a favorire, particolarmente per i medici a tempo pieno, l'esercizio delle attivita' didattiche e scientifiche e ad ottenere, su richiesta, il comando per ragioni di aggiornamento tecnico scientifico; 6) fissare le modalita' per l'aggiornamento obbligatorio professionale del personale; 7) prevedere disposizioni per rendere omogeneo il trattamento economico complessivo e per equiparare gli istituti normativi aventi carattere economico del personale sanitario universitario operante nelle strutture convenzionate con quelli del personale delle unita' sanitarie locali. Ai fini di una efficace organizzazione dei servizi delle unita' sanitarie locali, le norme delegate di cui al comma precedente, oltre a demandare alla regione il potere di emanare norme per la loro attuazione ai sensi dell'articolo 117, ultimo comma, della Costituzione, dovranno prevedere: 1) criteri generali per la istituzione e la gestione da parte di ogni regione di ruoli nominativi regionali del personale del servizio sanitario nazionale addetto ai presidi, servizi ed uffici delle unita' sanitarie locali. Il personale in servizio presso le unita' sanitarie locali sara' collocato nei diversi ruoli in rapporto a titoli e criteri fissati con decreto del Ministro della sanita'. Tali ruoli hanno valore anche ai fini dei trasferimenti, delle promozioni e dei concorsi; 2) criteri generali per i comandi o per i trasferimenti nell'ambito del territorio regionale; 3) criteri generali per la regolamentazione, in sede di accordo nazionale unico, della mobilita' del personale; 4) disposizioni per disciplinare i concorsi pubblici, che devono essere banditi dalla regione su richiesta delle unita' sanitarie locali, e per la efficacia delle graduatorie da utilizzare anche ai fini del diritto di scelta tra i posti messi a concorso; 5) disposizioni volte a stabilire che nell'ambito delle singole unita' sanitarie locali l'assunzione avviene nella qualifica funzionale e non nel posto. I decreti delegati di cui al terzo comma del presente articolo prevedono altresi' norme riguardanti: a) i criteri per la valutazione, anche ai fini di pubblici concorsi, dei servizi e dei titoli di candidati che hanno svolto la loro attivita' o nelle strutture sanitarie degli enti di cui all'articolo 41 o in quelle convenzionate a norma dell'articolo 43 fatti salvi i diritti acquisiti ai sensi dell'articolo 129 del decreto del Presidente della Repubblica numero 130 del 27 marzo 1969; b) la quota massima dei posti vacanti che le regioni possono riservare, per un tempo determinato, a personale in servizio a rapporto di impiego continuativo presso strutture convenzionate che cessino il rapporto convenzionale nonche' le modalita' ed i criteri per i relativi concorsi; c) le modalita' ed i criteri per l'immissione nei ruoli regionali di cui al n. 1) del precedente comma, previo concorso riservato, del personale non di ruolo addetto esclusivamente e, in modo continuativo, ai servizi sanitari in data non successiva al 30 giugno 1978 ed in servizio all'atto dell'entrata in vigore della presente legge presso regioni, comuni, province, loro consorzi e istituzioni ospedaliere pubbliche. Le unita' sanitarie locali, per l'attuazione del proprio programma di attivita' e in relazione a comprovate ed effettive esigenze assistenziali, didattiche e di ricerca, previa autorizzazione della regione, individuano le strutture, le divisioni ed i servizi cui devono essere addetti sanitari a tempo pieno e prescrivono, anche in carenza della specifica richiesta degli interessati, a singoli sanitari delle predette strutture, divisioni e servizi, la prestazione del servizio a tempo pieno. In riferimento al comma precedente, i relativi bandi di concorso per posti vacanti prescrivono il rapporto di lavoro a tempo pieno. Il trattamento economico e gli istituti normativi di carattere economico del rapporto d'impiego di tutto il personale sono disciplinati mediante accordo nazionale unico, di durata triennale, stipulato tra il Governo, le regioni e l'Associazione nazionale dei comuni italiani (ANCI) e le organizzazioni sindacali maggiormente rappresentative in campo nazionale delle categorie interessate. La delegazione del Governo, delle regioni e dell'ANCI per la stipula degli accordi anzidetti e' costituita rispettivamente da un rappresentante della Presidenza del Consiglio dei ministri e dai Ministri della sanita', del lavoro e della previdenza sociale e del tesoro; da cinque rappresentanti designati dalle regioni attraverso la commissione interregionale di cui all'articolo 13 della legge 16 maggio 1970, n. 281; da sei rappresentanti designati dell'ANCI. L'accordo nazionale di cui al comma precedente e' reso esecutivo con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri. I competenti organi locali adottano entro 30 giorni dalla pubblicazione del suddetto decreto i necessari e dovuti atti deliberativi. E' fatto divieto di concedere al personale delle unita' sanitarie locali compensi, indennita' o assegni di qualsiasi genere e natura che modifichino direttamente o indirettamente il trattamento economico previsto dal decreto di cui al precedente comma. Allo scopo di garantire la parificazione delle lingue italiana e tedesca nel servizio sanitario, e' fatta salva l'indennita' di bilinguismo in provincia di Bolzano. Gli atti adottati in contrasto con la presente norma sono nulli di diritto e comportano la responsabilita' personale degli amministratori. ((COMMA ABROGATO DAL D.LGS. 15 MARZO 2010, N. 66)) (2)

--------------- AGGIORNAMENTO (2) La L. 22 ottobre 1979, n. 510, ha disposto (con l'art. 1, comma 1) che la delega conferita al Governo con il presente articolo, scaduta il 30 giugno 1979, e' rinnovata sino al 20 dicembre 1979. Ha inoltre disposto (con l'art. 1, comma 2) che "Ai soli fini dell'esercizio della delega di cui al comma precedente, i termini previsti nell'articolo 8 della legge 22 luglio 1975, n. 382, sono ridotti alla meta'".

### Art. 48. - (Personale a rapporto convenzionale)

L'uniformita' del trattamento economico e normativo del personale sanitario a rapporto convenzionale e' garantita sull'intero territorio nazionale da convenzioni, aventi durata triennale, del tutto conformi agli accordi collettivi nazionali stipulati tra il Governo, le regioni e l'Associazione nazionale dei comuni italiani (ANCI) e le organizzazioni sindacali maggiormente rappresentative in campo nazionale di ciascuna categoria. La delegazione del Governo, delle regioni e dell'ANCI per la stipula degli accordi anzidetti e' costituita rispettivamente dai Ministri della sanita', del lavoro e della previdenza sociale e del tesoro; da cinque rappresentanti designati dalle regioni attraverso la commissione interregionale di cui all'articolo 13 della legge 16 maggio 1970, n. 281; da sei rappresentanti designati dall'ANCI. ((16)) L'accordo nazionale di cui al comma precedente e' reso esecutivo con decreto del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri. I competenti organi locali adottano entro 30 giorni dalla pubblicazione del suddetto decreto i necessari e dovuti atti deliberativi. Gli accordi collettivi nazionali di cui al primo comma devono prevedere: 1) il rapporto ottimale medico-assistibili per la medicina generale e quella pediatrica di libera scelta, al fine di determinare il numero dei medici generici e dei pediatri che hanno diritto di essere convenzionati in ogni unita' sanitaria locale, fatto salvo il diritto di libera scelta del medico per ogni cittadino; 2) l'istituzione e i criteri di formazione di elenchi unici per i medici generici, per i pediatri, per gli specialisti convenzionati esterni e per gli specialisti e generici ambulatoriali; 3) l'accesso alla convenzione, che e' consentito ai medici con rapporto di impiego continuativo a tempo definito; 4) la disciplina delle incompatibilita' e delle limitazioni del rapporto convenzionale rispetto ad altre attivita' mediche, al fine di favorire la migliore distribuzione del lavoro medico e la qualificazione delle prestazioni; 5) il numero massimo degli assistiti per ciascun medico generico e pediatra di libera scelta a ciclo di fiducia ed il massimo delle ore per i medici ambulatoriali specialisti e generici, da determinare in rapporto ad altri impegni di lavoro compatibili; la regolamentazione degli obblighi che derivano al medico in dipendenza del numero degli assistiti o delle ore; il divieto di esercizio della libera professione nei confronti dei propri convenzionati; le attivita' libero-professionali incompatibili con gli impegni assunti nella convenzione. Eventuali deroghe in aumento al numero massimo degli assistiti e delle ore di servizio ambulatoriale potranno essere autorizzate in relazione a particolari situazioni locali e per un tempo determinato dalle regioni, previa domanda motivata alla unita' sanitaria locale; 6) l'incompatibilita' con qualsiasi forma di cointeressenza diretta o indiretta e con qualsiasi rapporto di interesse con case di cura private e industrie farmaceutiche. Per quanto invece attiene al rapporto di lavoro si applicano le norme previste dal precedente punto 4); 7) la differenziazione del trattamento economico a seconda della quantita' e qualita' del lavoro prestato in relazione alle funzioni esercitate nei settori della prevenzione, cura e riabilitazione. Saranno fissate a tal fine tariffe socio-sanitarie costituite, per i medici generici e per i pediatri di libera scelta, da un compenso globale annuo per assistito; e, per gli specialisti e generici ambulatoriali, da distinti compensi commisurati alle ore di lavoro prestato negli ambulatori pubblici e al tipo e numero delle prestazioni effettuate presso gli ambulatori convenzionati esterni. Per i pediatri di libera scelta potranno essere previste nell'interesse dell'assistenza forme integrative di remunerazione; 8) le forme di controllo sull'attivita' dei medici convenzionati, nonche' le ipotesi di infrazione da parte dei medici degli obblighi derivanti dalla convenzione, le conseguenti sanzioni, compresa la risoluzione del rapporto convenzionale, e il procedimento per la loro irrogazione, salvaguardando il principio della contestazione degli addebiti e fissando la composizione di commissioni paritetiche di disciplina; 9) le forme di incentivazione in favore dei medici convenzionati residenti in zone particolarmente disagiate, anche allo scopo di realizzare una migliore distribuzione territoriale dei medici; 10) le modalita' per assicurare l'aggiornamento obbligatorio professionale dei medici convenzionati; 11) le modalita' per assicurare la continuita' dell'assistenza anche in assenza o impedimento del medico tenuto alla prestazione; 12) le forme di collaborazione fra i medici, il lavoro medico di gruppo e integrato nelle strutture sanitarie e la partecipazione dei medici a programmi di prevenzione e di educazione sanitaria; 13) la collaborazione dei medici, per la parte di loro competenza, alla compilazione di libretti sanitari personali di rischio. I criteri di cui al comma precedente, in quanto applicabili, si estendono alle convenzioni con le altre categorie non mediche di operatori professionali, da stipularsi con le modalita' di cui al primo e secondo comma del presente articolo. Gli stessi criteri, per la parte compatibile, si estendono, altresi', ai sanitari che erogano le prestazioni specialistiche e di riabilitazione in ambulatori dipendenti da enti o istituti privati convenzionati con la regione. Le disposizioni di cui al presente articolo si applicano anche alle convenzioni da stipulare da parte delle unita' sanitarie locali con tutte le farmacie di cui all'articolo 28. E' nullo qualsiasi atto, anche avente carattere integrativo, stipulato con organizzazioni professionali o sindacali per la disciplina dei rapporti convenzionali. Resta la facolta' degli organi di gestione delle unita' sanitarie locali di stipulare convenzioni con ordini religiosi per l'espletamento di servizi nelle rispettive strutture. E' altresi' nulla qualsiasi convenzione con singoli appartenenti alle categorie di cui al presente articolo. Gli atti adottati in contrasto con la presente norma comportano la responsabilita' personale degli amministratori. Le federazioni degli ordini nazionali, nonche' i collegi professionali, nel corso delle trattative per la stipula degli accordi nazionali collettivi riguardanti le rispettive categorie, partecipano in modo consultivo e limitatamente agli aspetti di carattere deontologico e agli adempimenti che saranno ad essi affidati dalle convenzioni uniche. Gli ordini e collegi professionali sono tenuti a dare esecuzione ai compiti che saranno ad essi demandati dalle convenzioni uniche. Sono altresi' tenuti a valutare sotto il profilo deontologico i comportamenti degli iscritti agli albi professionali che si siano resi inadempienti agli obblighi convenzionali, indipendentemente dalle sanzioni applicabili a norma di convenzione. In caso di grave inosservanza delle disposizioni di cui al comma precedente, la regione interessata provvede a farne denuncia al Ministro della sanita' e a darne informazione contemporaneamente alla competente federazione nazionale dell'ordine. Il Ministro della sanita', sentita la suddetta federazione, provvede alla nomina di un commissario, scelto tra gli iscritti nell'albo professionale della provincia, per il compimento degli atti cui l'ordine provinciale non ha dato corso. Sino a quando non sara' riordinato con legge il sistema previdenziale relativo alle categorie professionistiche convenzionate, le convenzioni di cui al presente articolo prevedono la determinazione della misura dei contributi previdenziali e le modalita' del loro versamento a favore dei fondi di previdenza di cui al decreto del Ministro del lavoro e della previdenza sociale in data 15 ottobre 1976, pubblicato nel supplemento alla Gazzetta Ufficiale della Repubblica del 28 ottobre 1976, n. 289.

--------------- AGGIORNAMENTO (16) La L. 27 dicembre 1983, n. 730, ha disposto (con l'art. 24, comma 3) che "In applicazione dei principi di contestualita' e di omogeneizzazione affermati nell'articolo 20 del decreto del Presidente della Repubblica 25 giugno 1983, n. 348, in deroga al primo comma del citato articolo 48 della legge 23 dicembre 1978, n. 833, gli accordi convenzionali, in scadenza o gia' scaduti al 31 dicembre 1983, sono rinnovati con scadenza al 30 giugno 1985".

## CONTROLLI, CONTABILITA' E FINANZIAMENTO

### Art. 49. - (Controlli sulle unita' sanitarie locali)

Il controllo sugli atti delle unita' sanitarie locali e' esercitato, in unica sede, dai comitati regionali di controllo di cui all'articolo 55 della legge 10 febbraio 1953, n. 62, integrati da un esperto in materia sanitaria designato dal Consiglio regionale e da un rappresentante del Ministero del tesoro, nelle forme previste dagli articoli 59 e seguenti della medesima legge. I provvedimenti vincolati della unita' sanitaria locale attinenti allo stato giuridico e al trattamento economico del personale dipendente indicati nell'articolo 10, secondo comma, del decreto del Presidente della Repubblica 30 giugno 1972, n. 748, sono adottati dal coordinatore amministrativo dell'ufficio di direzione e trasmessi al comitato di gestione e al collegio dei revisori. Detti provvedimenti non sono assoggettati al controllo del comitato regionale di controllo. Il comitato di gestione, d'ufficio o su segnalazione del collegio dei revisori, nell'esercizio del potere di autotutela puo', entro 20 giorni dal ricevimento, annullare o riformare i provvedimenti indicati al comma precedente. ((Gli atti delle unita' sanitarie locali sono nulli di diritto se per la relativa spesa non e' indicata idonea copertura finanziaria.)) Le modificazioni apportate in sede di riordinamento delle autonomie locali alla materia dei controlli sugli atti e sugli organi dei comuni e delle province s'intendono automaticamente estese ai controlli sulle unita' sanitarie locali. I controlli di cui ai commi precedenti per le regioni a statuto speciale e per le province autonome di Trento e di Bolzano si esercitano nelle forme previste dai rispettivi statuti. I comuni singoli o associati e le comunita' montane presentano annualmente, in base a criteri e principi uniformi predisposti dalle regioni, allegata al bilancio delle unita' sanitarie locali, una relazione al presidente della giunta regionale sui livelli assistenziali raggiunti e sulle esigenze che si sono manifestate nel corso dell'esercizio. Il presidente della giunta regionale presenta annualmente al consiglio regionale una relazione generale sulla gestione ed efficienza dei servizi sanitari, con allegata la situazione contabile degli impegni assunti sulla quota assegnata alla regione degli stanziamenti per il servizio sanitario nazionale. Tale relazione deve essere trasmessa ai Ministri della sanita', del tesoro e del lavoro e della previdenza sociale, con allegato un riepilogo dei conti consuntivi, per singole voci, delle unita' sanitarie locali.

### Art. 50.

(Norme di contabilita) Entro sei mesi dalla entrata in vigore della presente legge le regioni provvedono con legge a disciplinare l'utilizzazione del patrimonio e la contabilita' delle unita' sanitarie locali in conformita' ai seguenti principi: 1) la disciplina amministrativo-contabile delle gestioni deve risultare corrispondente ai principi della contabilita' pubblica previsti dalla legislazione vigente; 2) i competenti organi dei comuni, singoli o associati, e delle comunita' montane interessati cureranno l'effettuazione di periodiche verifiche di cassa, con ritmo almeno bimestrale, al fine dell'accertamento di eventuali disavanzi, da comunicare immediatamente ai sindaci o ai presidenti delle comunita' competenti per l'adozione dei provvedimenti di cui all'ultimo comma del presente articolo; 3) i bilanci devono recare analitiche previsioni tanto in termini di competenze quanto in termini di cassa; 4) i predetti bilanci, in cui saranno distinte le gestioni autonome e le contabilita' speciali, devono essere strutturati su base economica; 5) i conti consuntivi devono contenere una compiuta dimostrazione, oltre che dei risultati finanziari, di quelli economici e patrimoniali delle gestioni; 6) le risultanze complessive delle previsioni di entrata e di spesa nonche' dei conti consuntivi delle unita' sanitarie locali, devono essere iscritte rispettivamente nel bilancio di previsione e nel conto consuntivo dei comuni singoli o associati o delle comunita' montane. I bilanci di previsione e i conti consuntivi delle unita' sanitarie locali debbono essere allegati alle contabilita' degli enti territoriali cui si riferiscono; 7) gli stanziamenti iscritti in entrata ed in uscita dei bilanci comunali o delle comunita' montane per i compiti delle unita' sanitarie locali debbono comprendere i relativi affidamenti regionali che non possono essere utilizzati in alcun caso per altre finalita'; 8) i contratti di fornitura non possono essere stipulati con dilazioni di pagamento superiori a 90 giorni; 9) alle unita' sanitarie locali e' vietato, anche attraverso i comuni, il ricorso a qualsiasi forma di indebitamento salvo anticipazioni mensili da parte del tesoriere pari a un dodicesimo dello scoperto autorizzato. ((10) l'obbligo di prevedere, nell'ordinamento contabile delle unita' sanitarie locali, l'adeguamento della classificazione economica e funzionale della spesa, della denominazione dei capitoli delle entrate e delle spese nonche' dei relativi codici, ai criteri stabiliti con decreto del Presidente della Repubblica, su proposta del Ministro del tesoro di concerto con il Ministro della sanita', sentita la commissione interregionale di cui all'articolo 13 della legge 16 maggio 1970, n. 281, da emanarsi entro il 30 giugno 1980. Fino all'emanazione del predetto decreto del Presidente della Repubblica, l'ordinamento contabile delle unita' sanitarie locali, per quanto attiene al presente obbligo, dovra' essere conforme ai criteri contenuti nelle leggi di bilancio e di contabilita' delle rispettive regioni di appartenenza.)) Le unita' sanitarie locali debbono fornire alle regioni rendiconti trimestrali, entro il termine perentorio di 30 giorni dalla data di scadenza del trimestre, in cui si dia conto dell'avanzo o disavanzo di cassa nonche' dei debiti e crediti dei bilanci gia' accertati alla data della resa del conto anzidetto, dettagliando gli eventuali impedimenti obiettivi per cui, decorso il termine di cui al numero 8) del primo comma, non sono stati effettuati pagamenti per forniture. ((Nei casi di inosservanza del termine suindicato, le regioni sono tenute a provvedere all'acquisizione dei rendiconti stessi, entro i successivi trenta giorni.)) La regione a sua volta fornira' gli stessi dati ai Ministeri della sanita' e del tesoro secondo un modello di rilevazione contabile delle spese del servizio sanitario nazionale impostato uniformemente nell'ambito dell'indirizzo e coordinamento governativo. Ove dalla comunicazione di cui al numero 2) del primo comma, ovvero dalla rendicontazione trimestrale prevista dal secondo comma del presente articolo, risulti che la gestione manifesta un disavanzo complessivo, e cio' anche avendo riguardo ai debiti e crediti di bilancio, i comuni, singoli o associati, e le comunita' montane sono tenuti a convocare nel termine di 30 giorni i rispettivi organi deliberanti al fine di adottare i provvedimenti necessari a riportare in equilibrio il conto di gestione della unita' sanitaria locale.

### Art. 51. - (Finanziamento del servizio sanitario nazionale)

Il fondo sanitario nazionale destinato al finanziamento del servizio sanitario nazionale e' annualmente determinato ((con la legge di cui al successivo articolo 53)). Gli importi relativi devono risultare stanziati in distinti capitoli della parte corrente e della parte in conto capitale da iscriversi, rispettivamente, negli stati di previsione della spesa del Ministero del tesoro e del Ministero del bilancio e della programmazione economica. Le somme stanziate a norma del precedente comma vengono ripartite con delibera del Comitato interministeriale per la programmazione economica (CIPE) tra tutte le regioni, comprese quelle a statuto speciale, su proposta del Ministro della sanita', sentito il Consiglio sanitario nazionale, tenuto conto delle indicazioni contenute nei piani sanitari nazionali e regionali e sulla base di indici e di standards distintamente definiti per la spesa corrente e per la spesa in conto capitale. Tali indici e standards devono tendere a garantire i livelli di prestazioni sanitarie stabiliti con le modalita' di cui al secondo comma dell'articolo 3 in modo uniforme su tutto il territorio nazionale, eliminando progressivamente le differenze strutturali e di prestazioni tra le regioni. Per la ripartizione della spesa in conto capitale si applica quanto disposto dall'articolo 43 del testo unico delle leggi sul Mezzogiorno approvato con decreto del Presidente della Repubblica 30 giugno 1967, numero 1523, prorogato dall'articolo 7 della legge 6 ottobre 1971, n. 853. All'inizio di ciascun trimestre, il Ministro del tesoro ed il Ministro del bilancio e della programmazione economica, ciascuno per la parte di sua competenza, trasferiscono alle regioni le quote loro assegnate ai sensi del presente articolo. In caso di mancato o ritardato invio ai Ministri della sanita' e del tesoro, da parte della regione, dei dati di cui al terzo comma del precedente articolo 50, le quote di cui al precedente comma vengono trasferite alla regione in misura uguale alle corrispondenti quote dell'esercizio precedente. Le regioni, sulla base di parametri numerici da determinarsi, sentiti i comuni, con legge regionale ed intesi ad unificare il livello delle prestazioni sanitarie, provvedono a ripartire tra le unita' sanitarie locali la quota loro assegnata per il finanziamento delle spese correnti, riservandone un'aliquota non superiore al 5 per cento per interventi imprevisti. Tali parametri devono garantire gradualmente livelli di prestazioni uniformi nell'intero territorio regionale. Per il riparto della quota loro assegnata per il finanziamento delle spese in conto capitale, le regioni provvedono sulla base delle indicazioni formulate dal piano sanitario nazionale. Con provvedimento regionale, all'inizio di ciascun trimestre, e' trasferita alle unita' sanitarie locali, tenendo conto dei presidi e servizi di cui all'articolo 18, la quota ad esse spettante secondo il piano sanitario regionale. Gli amministratori e i responsabili dell'ufficio di direzione dell'unita' sanitaria locale sono responsabili in solido delle spese disposte od autorizzate in eccedenza alla quota di dotazione loro attribuita, salvo che esse non siano determinate da esigenze obiettive di carattere locale da collegare a fattori straordinari di morbilita' accertati dagli organi sanitari della regione e finanziabili con la riserva di cui al quarto comma.

### Art. 52. - (Finanziamento per l'esercizio finanziario 1979)

Per l'esercizio finanziario 1979 l'importo del fondo sanitario nazionale, parte corrente, da iscrivere nel bilancio dello Stato e' determinato, con riferimento alle spese effettivamente sostenute nel 1977 dallo Stato, dalle regioni, dalle province, dai comuni e loro consorzi, dagli enti, casse, servizi e gestioni autonome estinti e posti in liquidazione ai sensi dell'articolo 12-bis del decreto-legge 8 luglio 1974, n. 264, come modificato dalla legge di conversione 17 agosto 1974, n. 386, e da ogni altro ente pubblico previsto dalla presente legge, per lo esercizio delle funzioni attribuite al servizio sanitario nazionale. Ai fini della determinazione del fondo sanitario nazionale per l'esercizio 1979, sulle spese impegnate nel 1977 vengono riconosciute in aumento: a) le maggiorazioni derivanti dall'applicazione delle norme contrattuali, regolamentari o legislative vigenti per quanto riguarda la spesa del personale, compreso quello il cui rapporto e' regolato da convenzioni; b) la maggiorazione del 7 per cento delle spese impegnate per la fornitura di beni e servizi per ciascuno degli anni 1978 e 1979; c) le maggiorazioni derivanti dalle rate di ammortamento dei mutui regolarmente contratti negli anni 1978 e precedenti e non compresi negli impegni dell'anno 1977. Fatte salve le necessita' finanziarie degli organi centrali del servizio sanitario nazionale e degli enti pubblici di cui al primo comma, alla ripartizione del fondo fra le regioni si provvede per l'esercizio 1979, anche in deroga al disposto dell'articolo 8 della legge 16 maggio 1970, n. 281, con decreto del Ministro del tesoro di concerto con il Ministro della sanita', assumendo come riferimento la spesa rilevata nelle singole regioni, secondo quanto e' previsto dal presente articolo, maggiorata in base alle disposizioni di cui al precedente comma. Le regioni, tenuto conto di quanto disposto dal terzo comma dell'articolo 61 e sulla base degli atti ricognitivi previsti dall'articolo 7 della legge 4 agosto 1978, n. 461, assicurano, con periodicita' trimestrale i necessari mezzi finanziari agli enti che nel territorio regionale esercitano le funzioni del servizio sanitario nazionale fino all'effettivo trasferimento delle stesse alle unita' sanitarie locali. Agli enti medesimi si applicano anche, nel periodo considerato, le disposizioni di cui ai numeri 8) e 9) del primo comma dell'articolo 50. Gli enti e le regioni, per la parte di rispettiva competenza, sono tenuti agli adempimenti di cui ai commi secondo e terzo dell'articolo 50. Ove dai rendiconti trimestrali risulti che la gestione manifesti un disavanzo rispetto al piano economico contabile preso a base per il finanziamento dell'ente, la regione indica tempestivamente i provvedimenti necessari a riportare in equilibrio il conto di gestione. ((1))

--------------- AGGIORNAMENTO (1) IL D.L. 26 maggio 1979, n. 154, convertito con modificazioni dalla L. 27 luglio 1979, n. 300, ha disposto (con l'art. 1, comma 2) che "In deroga all'art. 52 della stessa legge 23 dicembre 1978, n. 833, per l'anno 1979 il fabbisogno finanziario dell'assistenza sanitaria delle province, comuni e loro consorzi resta assicurato nell'ambito delle disposizioni in materia di finanza locale dettate dalla legge 21 dicembre 1978, n. 843".

## PROCEDURE DI PROGRAMMAZIONE E DI ATTUAZIONE DEL SERVIZIO SANITARIO NAZIONALE

### Art. 53. - (Piano sanitario nazionale)

Le linee generali di indirizzo e le modalita' di svolgimento delle attivita' istituzionali del Servizio sanitario nazionale sono stabilite con il piano sanitario nazionale in conformita' agli obiettivi della programmazione socio-economica nazionale e tenuta presente l'esigenza di superare le condizioni di arretratezza socio-sanitaria che esistono nel Paese, particolarmente nelle regioni meridionali. Il piano sanitario nazionale viene predisposto dal Governo su proposta del Ministro della sanita', sentito il Consiglio sanitario nazionale. Il piano sanitario nazionale e' sottoposto dal Governo al Parlamento ai fini della sua approvazione con atto non legislativo. Contestualmente alla trasmissione da parte del Governo al Parlamento del piano sanitario nazionale, il Governo presenta al Parlamento il disegno di legge contenente sia le disposizioni precettive ai fini della applicazione del piano sanitario nazionale, sia le norme per il finanziamento pluriennale del servizio sanitario nazionale, rapportate alla durata del piano stesso, con specifica indicazione degli importi da assegnare al fondo sanitario nazionale ai sensi dell'articolo 51 della presente legge e dei criteri di ripartizione alle regioni. Il Parlamento esamina ed approva contestualmente il piano sanitario nazionale, le norme precettive di applicazione e le norme di finanziamento pluriennale. Il Governo adotta i conseguenti atti di indirizzo e coordinamento, sentito il Consiglio sanitario nazionale, il cui parere si intende positivo se non espresso entro sessanta giorni dalla richiesta. Il piano sanitario nazionale ha di norma durata triennale e puo' essere modificato nel corso del triennio con il rispetto delle modalita' di cui al presente articolo. Il piano sanitario nazionale, le disposizioni precettive e le norme finanziarie pluriennali di cui al precedente quinto comma sono approvati e trasmessi dal Governo al Parlamento nel corso dell'ultimo anno di vigenza del piano precedente, in tempo utile per consentirne l'approvazione entro il 1 settembre dell'anno stesso. Le regioni predispongono e approvano i propri piani sanitari regionali entro il successivo mese di novembre. Il piano sanitario nazionale stabilisce per il periodo della sua durata: a) gli obiettivi da realizzare nel triennio con riferimento a quanto disposto dall'articolo 2; b) LETTERA ABROGATA DALLA L. 23 OTTOBRE 1985, N. 595; c) gli indici e gli standards nazionali da assumere per la ripartizione del fondo sanitario nazionale tra le regioni, al fine di realizzare in tutto il territorio nazionale un'equilibrata organizzazione dei servizi, anche attraverso una destinazione delle risorse per settori fondamentali di intervento, con limiti differenziati per gruppi di spese correnti e per gli investimenti, prevedendo in particolare gli indici nazionali e regionali relativi ai posti letto e la ripartizione quantitativa degli stessi. Quanto agli investimenti il piano deve prevedere che essi siano destinati alle regioni nelle quali la dotazione di posti letto e di altri presidi e strutture sanitarie risulti inferiore agli indici normali indicati dal piano stesso. Ai fini della valutazione della priorita' di investimento il piano tiene conto anche delle disponibilita', nelle varie regioni, di posti letto, presidi e strutture sanitarie di istituzioni convenzionate. Il piano prevede inoltre la sospensione di ogni investimento (se non per completamenti e ristrutturazioni dimostrate assolutamente urgenti ed indispensabili) nelle regioni la cui dotazione di posti letto e di altri presidi e strutture sanitarie raggiunge o supera i suddetti indici; d) gli indirizzi ai quali devono uniformarsi le regioni nella ripartizione della quota regionale ad esse assegnata fra le unita' sanitarie locali; e) i criteri e gli indirizzi ai quali deve riferirsi la legislazione regionale per la organizzazione dei servizi fondamentali previsti dalla presente legge e per gli organici del personale addetto al servizio sanitario nazionale; f) le norme generali di erogazione delle prestazioni sanitarie, nonche' le fasi o le modalita' della graduale unificazione delle stesse e del corrispondente adeguamento, salvo provvedimenti di fiscalizzazione dei contributi assicurativi; g) gli indirizzi ai quali devono riferirsi i piani regionali di cui al successivo articolo 55, ai fini di una coordinata e uniforme realizzazione degli obiettivi di cui alla precedente lettera a); h) gli obiettivi fondamentali relativi alla formazione e all'aggiornamento del personale addetto al servizio sanitario nazionale, con particolare riferimento alle funzioni tecnico-professionali, organizzative e gestionali e alle necessita' quantitative dello stesso; i) le procedure e le modalita' per verifiche periodiche dello stato di attuazione del piano e della sua idoneita' a perseguire gli obiettivi che sono stati previsti; l) le esigenze prioritarie del servizio sanitario nazionale in ordine alla ricerca biomedica e ad altri settori attinenti alla tutela della salute. ((COMMA ABROGATO DAL D. LGS. 30 GIUGNO 1993, N. 266)). ((COMMA ABROGATO DAL D. LGS. 30 GIUGNO 1993, N. 266)). (18)

--------------- AGGIORNAMENTO (18) La L. 23 ottobre 1985, n. 595, ha disposto (con l'art. 13, comma 4) che: "Nella prima applicazione, in deroga a quanto disposto dall'articolo 53 della legge 23 dicembre 1978 n. 833, come modificato, da ultimo, dall'articolo 1 della presente legge, il piano sanitario nazionale per il triennio 1986-88 e' presentato dal Governo al Parlamento ai fini della sua approvazione con atto non legislativo entro quarantacinque giorni dalla data di entrata in vigore della presente legge. Contestualmente alla presentazione del piano sanitario nazionale per il triennio 1986-88 il Governo presenta al Parlamento un disegno di legge contenente i criteri e le procedure per la ripartizione del fondo sanitario nazionale per gli anni 1986-88".

### Art. 54. - (Primo piano sanitario nazionale)

Il piano sanitario nazionale per il triennio 1980-1982 deve essere presentato al Parlamento entro il 30 aprile 1979. Fino all'approvazione del piano sanitario nazionale e' vietato disporre investimenti per nuove strutture immobiliari e per nuovi impianti di presidi sanitari. ((Particolari, motivate deroghe, possono essere consentite, su richiesta delle regioni, con decreto del Ministro della sanita', sentito il Consiglio sanitario nazionale)).

### Art. 55. - (Piani sanitari regionali)

Le regioni provvedono all'attuazione del servizio sanitario nazionale in base a piani sanitari triennali, coincidenti con il triennio del piano sanitario nazionale, finalizzati alla eliminazione degli squilibri esistenti nei servizi e nelle prestazioni nel territorio regionale. I piani sanitari triennali delle regioni, che devono uniformarsi ai contenuti ed agli indirizzi del piano sanitario nazionale di cui all'articolo 53 e riferirsi agli obiettivi del programma regionale di sviluppo, sono predisposti dalla giunta regionale, secondo la procedura prevista nei rispettivi statuti per quanto attiene alla consultazione degli enti locali e delle altre istituzioni ed organizzazioni interessate. I piani sanitari triennali delle regioni sono approvati con legge regionale almeno 120 giorni prima della scadenza di ogni triennio. Ai contenuti ed agli indirizzi del piano regionale debbono uniformarsi gli atti e provvedimenti emanati dalle regioni.

### Art. 56. - (Primi piani sanitari regionali)

Per il triennio 1980-1982 i singoli piani sanitari regionali sono predisposti ed approvati entro il 30 ottobre 1979 e devono fra l'altro prevedere: a) l'importo delle quote da iscrivere per ogni anno del triennio nel bilancio della regione con riferimento alle indicazioni del piano sanitario nazionale; b) le modalita' per attuare, nelle unita' sanitarie locali della regione, l'unificazione delle prestazioni sanitarie secondo quanto previsto dal quarto comma, lettera f), dell'articolo 53; c) gli indirizzi ai quali devono riferirsi gli organi di gestione delle unita' sanitarie locali nella fase di avvio del servizio sanitario nazionale.

### Art. 57. - (Unificazione dei livelli delle prestazioni sanitarie)

Con decreti del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro della sanita' di concerto con il Ministro del tesoro, sentito il Consiglio sanitario nazionale da emanarsi in conformita' a quanto previsto dal piano sanitario nazionale di cui all'articolo 53, sono gradualmente unificate, nei tempi e nei modi stabiliti dal piano stesso, le prestazioni sanitarie gia' erogate dai disciolti enti mutualistici, dalle mutue aziendali e dagli enti, casse, servizi e gestioni autonome degli enti previdenziali. Con decreti del Presidente della Repubblica, previa deliberazione del Consiglio dei ministri, su proposta del Ministro del lavoro e della previdenza sociale, di concerto con i Ministri del tesoro e della sanita', ed anche in conformita' a quanto previsto dalla lettera f), quarto comma, dell'articolo 53, si provvede a disciplinare l'adeguamento della partecipazione contributiva degli assistiti nonche' le modalita' e i tempi di tale partecipazione in funzione della soppressione delle strutture mutualistiche di cui al primo comma del presente articolo. Sono comunque fatte salve le prestazioni sanitarie specifiche, preventive, ortopediche e protesiche, erogate, ai sensi delle leggi e dei regolamenti vigenti, a favore degli invalidi per causa di guerra e di servizio, dei ciechi, dei sordomuti e degli invalidi civili. Nulla e' innovato alle disposizioni del decreto del Presidente della Repubblica 30 giugno 1965, n. 1124, per quanto riguarda le prestazioni di assistenza sanitaria curativa e riabilitativa, che devono essere garantite, a prescindere dalla iscrizione di cui al terzo comma dell'articolo 19 della presente legge, agli invalidi del lavoro, ferma restando, altresi', l'esclusione di qualunque concorso di questi ultimi al pagamento delle prestazioni sanitarie. Con legge regionale e' disciplinato il coordinamento, anche mediante convenzioni, fra l'erogazione delle anzidette prestazioni e gli interventi sanitari che gli enti previdenziali gestori dell'assicurazione contro gli infortuni sul lavoro e le malattie professionali pongono in essere, in favore degli infortunati e tecnopatici, per realizzare le finalita' medico-legali di cui all'articolo 75 della presente legge.

### Art. 58. - (Servizio epidemiologico e statistico)

Nel piano sanitario nazionale di cui all'articolo 53 sono previsti specifici programmi di attivita' per la rilevazione e la gestione delle informazioni epidemiologiche, statistiche e finanziarie occorrenti per la programmazione sanitaria nazionale e regionale e per la gestione dei servizi sanitari. I programmi di attivita', per quanto attiene alle competenze attribuitegli dal precedente articolo 27, sono attuati dall'istituto superiore di sanita'. Le regioni, nell'ambito dei programmi di cui al primo comma, provvedono ai servizi di informatica che devono essere organizzati tenendo conto delle articolazioni del servizio sanitario nazionale. Con decreto del Ministro della sanita', sentito il Consiglio sanitario nazionale, sono dettate norme per i criteri in ordine alla scelta dei campioni di rilevazione e per la standardizzazione e comparazione dei dati sul piano nazionale e regionale.

### Art. 59. - (Riordinamento del Ministero della sanita')

Con legge dello Stato, entro il 30 giugno 1979, si provvede al riordinamento del Ministero della sanita', che dovra' essere strutturato per l'attuazione dei compiti che gli sono assegnati dalla presente legge, in osservanza dei criteri generali e dei principi direttivi in essa indicati ed in stretta correlazione con le funzioni che nell'ambito del servizio sanitario nazionale debbono essere esercitate dal Ministero medesimo. In sede di riordinamento del Ministero della sanita', sara' stabilita la dotazione organica degli uffici per il funzionamento del Consiglio sanitario nazionale. Con la stessa legge sono rideterminate le attribuzioni e le modalita' per la composizione del Consiglio superiore della sanita', con riferimento esclusivo alla natura di organo consultivo tecnico del Ministro della sanita' e in funzione dei compiti assunti dal Ministero della sanita' nell'ambito del servizio sanitario nazionale. In attesa della legge di cui al primo comma, il Ministro della sanita', con proprio decreto, costituisce, in via provvisoria, l'ufficio centrale della programmazione sanitaria, in relazione alle esigenze di cui all'articolo 53, e l'ufficio per l'attuazione della presente legge con compiti di studio e predisposizione dei provvedimenti legislativi ed amministrativi connessi alla istituzione del servizio sanitario nazionale, e provvede a definire gli ambiti funzionali dei nuovi uffici apportando le necessarie modifiche anche a quelli delle attuali direzioni generali. Ai predetti uffici ed al segretariato del Consiglio sanitario nazionale sono preposti funzionari con qualifica di dirigente generale. I posti previsti nella tabella XIX, quadro A, allegata al decreto del Presidente della Repubblica 30 giugno 1972, n. 748, sono aumentati di tre unita'. (5) Per le esigenze degli uffici di cui al terzo comma, la dotazione organica dei primi dirigenti, con funzioni di vice consigliere ministeriale, di cui al quadro B della richiamata tabella XIX, e' elevata di dieci unita'. Alla copertura dei posti complessivamente vacanti nella qualifica di primo dirigente si provvede ai sensi dell'articolo 1 della legge 30 settembre 1978, n. 583. (22) ((25))

--------------- AGGIORNAMENTO (5) La L. 11 luglio 1980, n. 312, ha disposto (con l'art. 169) che: "La norma di cui al terzo comma dell'articolo 59 della legge 23 dicembre 1978, n. 833, con la quale viene aumentato di 3 unita' il numero dei posti previsti nella tabella XIX, quadro A, allegata al decreto del Presidente della Repubblica 30 giugno 1972, n. 748, s'interpreta nel senso che, fino alla emanazione della legge di riordinamento del Ministero della sanita' all'ufficio centrale della programmazione sanitaria, all'ufficio per l'attuazione della legge istitutiva del Servizio sanitario nazionale e al segretariato del Consiglio sanitario nazionale sono preposti i dirigenti generali nominati in conseguenza del predetto aumento". --------------- AGGIORNAMENTO (22) Il D.Lgs. 30 giugno 1993, n. 266 ha disposto (con l'art. 10, comma 1) l'abrogazione del presente articolo; ha inoltre disposto (con l'art. 10, comma 2) che "L'abrogazione di cui al comma 1 ha efficacia dall'entrata in vigore dei regolamenti previsti dal presente decreto, in relazione alle materie di rispettiva competenza, e comunque a decorrere dal 1 gennaio 1994". --------------- AGGIORNAMENTO (25) Il D.Lgs. 30 giugno 1993, n. 266, come modificato dal D.L. 23 ottobre 1996, n. 542, convertito con modificazioni dalla L. 23 dicembre 1996, n. 649, ha disposto (con l'art. 10, comma 2) che l'abrogazione del presente articolo "ha efficacia dall'entrata in vigore dei regolamenti previsti dal presente decreto, in relazione alle materie di rispettiva competenza".

### Art. 60. - (Costituzione del Consiglio sanitario nazionale)

Entro 45 giorni dall'entrata in vigore della presente legge e' costituito il Consiglio sanitario nazionale di cui all'articolo

8. Il Consiglio sanitario nazionale, a partire dalla data del suo insediamento e fino alla conclusione delle operazioni di liquidazione degli enti e gestioni autonome preposti all'erogazione dell'assistenza sanitaria in regime mutualistico, assume i compiti attribuiti al comitato centrale di cui all'articolo 4 della legge 29 giugno 1977, n. 349. Fino all'adozione dei provvedimenti di cui all'ultimo comma dell'articolo 61 sono prorogati i compiti e i poteri affidati ai commissari liquidatori dagli articoli 3 e 7 della legge 29 giugno 1977, n. 349. Alle sedute del Consiglio sanitario nazionale convocate per l'esercizio dei compiti di cui al secondo comma partecipano con voto consultivo i cinque commissari liquidatori designati dal Ministro del lavoro e della previdenza sociale ed i cinque membri proposti dal CNEL di cui al secondo comma dell'articolo 4 della legge 29 giugno 1977, n. 349. Per l'assolvimento dei propri compiti il Consiglio sanitario nazionale si avvale, sino al riordinamento del Ministero della sanita' di cui al precedente articolo 59, dell'esistente segreteria del comitato centrale di cui all'articolo 4 della legge 29 giugno 1977, numero 349.

### Art. 61. - (Costituzione delle unita' sanitarie locali)

Le regioni, entro sei mesi dall'entrata in vigore della presente legge e secondo le norme di cui al precedente Titolo I, individuano gli ambiti territoriali delle unita' sanitarie locali, ne disciplinano con legge i compiti, la struttura, la gestione, l'organizzazione, il funzionamento e stabiliscono i criteri per l'articolazione delle unita' sanitarie locali in distretti sanitari di base. Con provvedimento da adottare entro il 31 dicembre 1979 secondo le norme dei rispettivi statuti le regioni costituiscono le unita' sanitarie locali. Le regioni, con lo stesso provvedimento di cui al comma precedente, adottano disposizioni: a) per il graduale trasferimento ai comuni, perche' siano attribuiti alle unita' sanitarie locali, delle funzioni, dei beni e delle attrezzature di cui sono attualmente titolari gli enti o gli uffici di cui, a norma della presente legge, vengano a cessare i compiti nelle materie proprie del servizio sanitario nazionale; b) per l'utilizzazione presso i servizi delle unita' sanitarie locali del personale gia' dipendente dagli enti od uffici di cui alla precedente lettera a) che a norma della presente legge e' destinato alle unita' sanitarie locali, nonche' per il trasferimento del personale medesimo dopo la definizione degli organici secondo quanto disposto nei provvedimenti assunti in attuazione di quanto previsto dal penultimo comma, punto 4, del precedente articolo 15; c) per la gestione finanziaria dei servizi di cui alla precedente lettera a) a partire dalla data di costituzione delle unita' sanitarie locali, con l'obbligo di fissare i limiti massimi di spesa consentiti per le retribuzioni del personale e per l'acquisto di beni e servizi e di prevedere periodici controlli della spesa e le responsabilita' in ordine alla stessa. Fino a quando non sara' stato emanato il provvedimento di cui al secondo comma del presente articolo, la tutela sanitaria delle attivita' sportive, nelle regioni che non abbiano emanato proprie norme in materia, continuera' ad essere assicurata, con l'osservanza dei principi generali contenuti nella legge 26 ottobre 1971, n. 1099, e delle normative stabilite dalle singole federazioni sportive riconosciute dal CONI, secondo i propri regolamenti.

### Art. 62. - (Riordinamento delle norme in materia di profilassi internazionale e di malattie infettive e diffusive)

Il Governo, entro due anni dall'entrata in vigore della presente legge, su proposta del Ministro della sanita', sentito il Consiglio di Stato, e' autorizzato, nel rispetto dei principi stabiliti dalla presente legge, a modificare, integrare, coordinare e riunire in testo unico le disposizioni vigenti in materia di profilassi internazionale, ivi compresa la zooprofilassi, e di malattie infettive e diffusive, ivi comprese le vaccinazioni obbligatorie, e le altre norme specifiche, tenendo conto dei principi, delle disposizioni e delle competenze previsti dalla presente legge. Sino all'emanazione del predetto testo unico, si applicano, in quanto non in contrasto con le disposizioni della presente legge, le norme del testo unico delle leggi sanitarie approvato con regio decreto 27 luglio 1934, n. 1265, e successive modificazioni ed integrazioni, nonche' le altre disposizioni vigenti in materia.

### Art. 63. - (Assicurazione obbligatoria)

A decorrere dal 1 gennaio 1980 l'assicurazione contro le malattie e' obbligatoria per tutti i cittadini. I cittadini che, secondo le leggi vigenti, non sono tenuti all'iscrizione ad un istituto mutualistico di natura pubblica sono assicurati presso il servizio sanitario nazionale nel limite delle prestazioni sanitarie erogate agli assicurati del disciolto INAM. ((A partire dalla data di cui al primo comma i cittadini di cui al comma precedente soggetti all'obbligo della presentazione della dichiarazione dei redditi ai fini dell'imposta sul reddito delle persone fisiche (IRPEF), sono tenuti a versare annualmente un contributo per l'assistenza di malattia, secondo le modalita' di cui ai commi seguenti, valido anche per i familiari che si trovino nelle condizioni indicate nel precedente comma. Il contributo dovuto dai cittadini italiani all'estero anche se non soggetti all'obbligo della predetta dichiarazione dei redditi e' disciplinato dal decreto di cui all'articolo 37 della presente legge. L'entita' del contributo e la modalita' di versamento per i cittadini italiani all'estero anche se non soggetti all'obbligo della predetta dichiarazione dei redditi sono disciplinate dal decreto di cui all'art. 37 della legge 23 dicembre 1978, n. 833.)) Con decreto del Ministro della sanita', da emanarsi entro il 30 ottobre di ogni anno di concerto con il Ministro del tesoro, sentito il Consiglio sanitario nazionale, e' stabilita ((...)) la quota annuale da porre a carico degli interessati per l'anno successivo. Detta quota e' calcolata tenendo conto delle variazioni previste nel costo medio pro capite dell'anno precedente per le prestazioni sanitarie di cui al secondo comma. Gli interessati verseranno la quota di cui al precedente comma mediante accreditamento in conto corrente postale intestato alla sezione di tesoreria provinciale di Roma con imputazione ad apposito capitolo da istituirsi nello stato di previsione dell'entrata del bilancio dello Stato. ((COMMA SOPPRESSO DAL D.L. 1 LUGLIO 1980, N. 312, CONVERTITO, CON MODIFICAZIONI DALLA L. 8 AGOSTO 1980, N. 441)) ((COMMA SOPPRESSO DAL D.L. 1 LUGLIO 1980, N. 312, CONVERTITO, CON MODIFICAZIONI DALLA L. 8 AGOSTO 1980, N. 441))

## NORME TRANSITORIE E FINALI

### Art. 64. - (Norme transitorie per l'assistenza psichiatrica)

La regione, nell'ambito del piano sanitario regionale, disciplina il graduale superamento degli ospedali psichiatrici o neuropsichiatrici e la diversa utilizzazione, correlativamente al loro rendersi disponibili delle strutture esistenti e di quelle in via di completamento. La regione provvede inoltre a definire il termine entro cui dovra' cessare la temporanea deroga per cui negli ospedali psichiatrici possono essere ricoverati, sempre che ne facciano richiesta, coloro che vi sono stati ricoverati anteriormente al 16 maggio 1978 e che necessitano di trattamento psichiatrico in condizioni di degenza ospedaliera; tale deroga non potra' comunque protrarsi oltre il 31 dicembre 1980. ((9)) Entro la stessa data devono improrogabilmente risolversi le convenzioni di enti pubblici con istituti di cura privati che svolgano esclusivamente attivita' psichiatrica. ((9)) E' in ogni caso vietato costruire nuovi ospedali psichiatrici, utilizzare quelli attualmente esistenti come divisioni specialistiche psichiatriche di ospedali generali, istituire negli ospedali generali divisioni o sezioni psichiatriche e utilizzare come tali divisioni o sezioni psichiatriche o sezioni neurologiche o neuro-psichiatriche. La regione disciplina altresi', con riferimento alle norme di cui agli articoli 66 e 68, la destinazione alle unita' sanitarie locali dei beni e del personale delle istituzioni pubbliche di assistenza e beneficenza (IPAB) e degli altri enti pubblici che all'atto dell'entrata in vigore della presente legge provvedono, per conto o in convenzione con le amministrazioni provinciali, al ricovero ed alla cura degli infermi di mente, nonche' la destinazione dei beni e del personale delle amministrazioni provinciali addetto ai presidi e servizi di assistenza psichiatrica e di igiene mentale. Quando tali presidi e servizi interessino piu' regioni, queste provvedono d'intesa. La regione, a partire dal 1 gennaio 1979, istituisce i servizi psichiatrici di cui all'articolo 35, utilizzando il personale dei servizi psichiatrici pubblici. Nei casi in cui nel territorio provinciale non esistano strutture pubbliche psichiatriche, la regione, nell'ambito del piano sanitario regionale e al fine di costituire i presidi per la tutela della salute mentale nelle unita' sanitarie locali, disciplina la destinazione del personale, che ne faccia richiesta, delle strutture psichiatriche private che all'atto dell'entrata in vigore della presente legge erogano assistenza in regime di convenzione, ed autorizza, ove necessario, l'assunzione per concorso di altro personale indispensabile al funzionamento di tali presidi. Sino all'adozione dei piani sanitari regionali di cui al primo comma i servizi di cui al quinto comma dell'articolo 34 sono ordinati secondo quanto previsto dal decreto del Presidente della Repubblica 27 marzo 1969, n. 128, al fine di garantire la continuita' dell'intervento sanitario a tutela della salute mentale, e sono dotati di un numero di posti letto non superiore a 15. Sino all'adozione dei provvedimenti delegati di cui all'articolo 47 le attribuzioni in materia sanitaria del direttore, dei primari, degli aiuti e degli assistenti degli ospedali psichiatrici sono quelle stabilite, rispettivamente, dagli articoli 4 e 5 e dall'articolo 7 dei decreto del Presidente della Repubblica 27 marzo 1969, n. 128. Sino all'adozione dei piani sanitari regionali di cui al primo comma i divieti di cui all'articolo 6 del decreto-legge 8 luglio 1974, n. 264, convertito con modificazioni nella legge 17 agosto 1974, n. 386, sono estesi agli ospedali psichiatrici e neuro-psichiatrici dipendenti dalle IPAB o da altri enti pubblici o dalle amministrazioni provinciali. Gli eventuali concorsi continuano ad essere espletati secondo le procedure applicate da ciascun ente prima della entrata in vigore della presente legge. Tra gli operatori sanitari di cui alla lettera i) dell'articolo 27 del decreto del Presidente della Repubblica 24 luglio 1977, numero 616, sono compresi gli infermieri di cui all'articolo 24 del regolamento approvato con regio decreto 16 agosto 1909, n. 615. Fermo restando quanto previsto dalla lettera q) dell'articolo 6 della presente legge la regione provvede all'aggiornamento e alla riqualificazione del personale infermieristico, nella previsione del superamento degli ospedali psichiatrici ed in vista delle nuove funzioni di tale personale nel complesso dei servizi per la tutela della salute mentale delle unita' sanitarie locali. Restano in vigore le norme di cui all'articolo 7, ultimo comma, della legge 13 maggio 1978, n. 180.

--------------- AGGIORNAMENTO (9) Il D.L. 30 aprile 1981, n. 168, convertito, con modificazioni, dalla L. 27 giugno 1981, n. 331 (in G.U. 30/06/1981, n. 177) ha disposto (con l'art. 3, comma 1) che: "I termini di cui al primo e al secondo comma dell'art. 64 della legge 23 dicembre 1978, n. 833, sono prorogati fino alla scadenza del trentesimo giorno dalla data di entrata in vigore del presente decreto".

### Art. 65. - (Attribuzione, per i servizi delle unita' sanitarie locali, di beni gia' di pertinenza degli enti mutualistici e delle gestioni sanitarie soppressi)

((In applicazione del progetto di riparto previsto dall'ultimo comma dell'articolo 4 della legge 29 giugno 1977, n. 349, e d'intesa con le regioni interessate, con decreto del Ministro del tesoro, di concerto con i Ministri del lavoro e della previdenza sociale e delle finanze, sia i beni mobili ed immobili che le attrezzature destinati prevalentemente ai servizi sanitari appartenenti agli enti, casse mutue e gestioni soppressi sono trasferiti al patrimonio dei comuni competenti per territorio, con vincolo di destinazione alle unita' sanitarie locali)). Con legge regionale sono disciplinati lo svincolo di destinazione dei beni di cui al precedente comma, il reimpiego ed il reinvestimento dei capitali ricavati dalla loro alienazione o trasformazione in opere di realizzazione e di ammodernamento dei presidi sanitari, nonche' la tutela dei beni culturali eventualmente ad essi connessi. Alle operazioni di trasferimento di cui al primo comma provvedono i commissari liquidatori di cui alla citata legge 29 giugno 1977, n. 349, che provvedono altresi' al trasferimento di tutti i rapporti giuridici relativi alle attivita' di assistenza sanitaria attribuite alle unita' sanitarie locali I rimanenti beni, ivi comprese le sedi in Roma delle Direzioni generali degli enti soppressi, sono realizzati dalla gestione di liquidazione ai sensi dell'articolo 77 ad eccezione dell'immobile sede della Direzione generale dell'INAM che e' attribuito al patrimonio dello Stato. Le regioni possono assegnare parte dei predetti beni in uso all'INPS, per la durata del primo piano sanitario nazionale, per le esigenze connesse allo svolgimento dei compiti di cui agli articoli 74 e 76 della presente legge, nonche' al Ministero del lavoro e della previdenza sociale per le esigenze delle sezioni circoscrizionali dell'impiego. Le Regioni assegnano parte dei beni di cui ali precedente comma in uso all'Istituto nazionale della previdenza sociale, per la durata del primo piano sanitario nazionale, per le esigenze connesse allo svolgimento di compiti di cui agli articoli 74 e 76 della presente legge, nonche' al Ministero del lavoro e della previdenza sociale per le esigenze delle sezioni circoscrizionali dell'impiego, secondo piani concordati con le Amministrazioni predette tenendo conto delle loro esigenze di efficienza e funzionalita'.

### Art. 66. - (Attribuzione, per i servizi delle unita' sanitarie locali, di beni gia' di pertinenza di enti locali)

Sono trasferiti al patrimonio del comune in cui sono collocati, con vincolo di destinazione alle unita' sanitarie locali: a) i beni mobili ed immobili e le attrezzature appartenenti alle province o a consorzi di enti locali e destinati ai servizi igienico-sanitari, ((...)); ((21)) b) i beni mobili ed immobili e le attrezzature degli enti ospedalieri, degli ospedali psichiatrici e neuro-psichiatrici e dei centri di igiene mentale dipendenti dalle province o da consorzi delle stesse o dalle istituzioni pubbliche di assistenza e beneficenza (IPAB) di cui al settimo comma dell'articolo 64, nonche' degli altri istituti di prevenzione e cura e dei presidi sanitari extraospedalieri dipendenti dalle province o da consorzi di enti locali. I rapporti giuridici relativi alle attivita' di assistenza sanitaria attribuite alle unita' sanitarie locali sono trasferiti ai comuni competenti per territorio. E' affidata alle unita' sanitarie locali la gestione dei beni mobili ed immobili e delle attrezzature destinati ai servizi igienico-sanitari dei comuni e all'esercizio di tutte le funzioni dei comuni e loro consorzi in materia igienico-sanitaria. Le regioni adottano gli atti legislativi ed amministrativi necessari per realizzare i trasferimenti di cui ai precedenti commi e per regolare i rapporti patrimoniali attivi e passivi degli enti ed istituti di cui alle lettere a) e b) del primo comma. Ai trasferimenti di cui al presente articolo si provvede con le modalita' e nei termini previsti dall'articolo 61. Con le stesse modalita' ed entro gli stessi termini gli enti ed istituti di cui alle lettere a) e b) del primo comma perdono, ove l'abbiano, la personalita' giuridica. Con legge regionale sono disciplinati lo svincolo di destinazione dei beni di cui al primo comma, il reimpiego ed il reinvestimento in opere di realizzazione e di ammodernamento dei presidi sanitari dei capitali ricavati dalla loro alienazione o trasformazione, nonche' la tutela dei beni culturali eventualmente ad essi connessi.

--------------- AGGIORNAMENTO (21) Il D.P.R. 5 giugno 1993, n. 177, ha disposto (con l'art. 1, comma 2) che l'abrogazione ha effetto decorsi sessanta giorni dalla data di pubblicazione del presente decreto nella Gazzetta Ufficiale.

### Art. 67. - (Norme per il trasferimento del personale degli enti mutualistici e delle gestioni sanitarie soppresse)

Entro il 30 giugno 1979, in applicazione del progetto di riparto previsto dall'ultimo comma dell'articolo 4 della legge 29 giugno 1977, n. 349, il Ministro della sanita' di concerto con i Ministri del lavoro e della previdenza sociale e del tesoro, sentito il Consiglio sanitario nazionale e le organizzazioni sindacali confederali rappresentate nel CNEL, stabilisce i contingenti numerici, distinti per amministrazione od ente e per qualifica, del personale da iscrivere nei ruoli regionali del personale addetto ai servizi delle unita' sanitarie locali, e del personale da assegnare all'Istituto nazionale della previdenza sociale, all'Istituto nazionale per l'assicurazione contro gli infortuni sul lavoro, e ad altri enti e pubbliche amministrazioni diverse da quelle statali, per le seguenti esigenze: a) per il fabbisogno di personale relativo ai servizi delle unita' sanitarie locali e per i compiti di cui agli articoli 74, 75 e 76; b) per la copertura dei posti in organico degli enti pubblici anzidetti, riservati ai sensi dell'articolo 43 della legge 20 marzo 1975, n. 70, cosi' come risultano dai provvedimenti attuativi dell'articolo 25 della suddetta legge. I medici ed i veterinari provinciali inquadrati nei ruoli regionali sono trasferiti al servizio sanitario nazionale e collocati nei ruoli di cui all'articolo 47, salvo diversa necessita' della regione. I contingenti numerici di cui al primo comma comprendono anche il personale dipendente, alla data del 1 dicembre 1977, dalle associazioni rappresentanti gli enti ospedalieri di cui all'articolo 40 della legge 12 febbraio 1968, n. 132; detto personale, per il quale viene risolto ad ogni effetto il precedente rapporto, sara' assunto presso le amministrazioni di destinazione previo accertamento dei requisiti di cui al precedente articolo 47, fatta eccezione per quello rappresentato dal limite di eta'. Entro il 31 dicembre 1979 i commissari liquidatori di cui alla legge 29 giugno 1977, n. 349, dispongono, su proposta formulata dalle regioni previa intesa con le organizzazioni sindacali maggiormente rappresentative in campo nazionale, il comando del personale presso le unita' sanitarie locali, nell'ambito dei contingenti di cui al primo comma e sulla base di criteri oggettivi di valutazione fissati dal Consiglio sanitario nazionale. Entro la stessa data i commissari liquidatori di cui alla legge 29 giugno 1977, n. 349, dispongono, su proposta del Ministro della sanita', previa intesa con le organizzazioni sindacali maggiormente rappresentative in campo nazionale, con riferimento ai contingenti di cui al primo comma e sulla base di criteri oggettivi di valutazione fissati dal Consiglio sanitario nazionale, il comando del personale presso enti e pubbliche amministrazioni diverse da quelle statali. Allo scadere dell'anno del comando di cui ai due precedenti commi tutto il personale comandato sia ai sensi della presente legge, che delle leggi 17 agosto 1974, n. 386, e 29 giugno 1977, n. 349, comunque utilizzato dalle regioni, e' trasferito alle stesse, alle unita' sanitarie locali ed alle amministrazioni ed enti presso cui presta servizio in una posizione giuridica e di livello funzionale corrispondente a quella ricoperta nell'ente o gestione di provenienza alla data del trasferimento stesso, secondo le tabelle di equiparazione previste dal terzo comma, n. 3), dell'articolo 47. Il personale non comandato ai sensi dei precedenti commi e' assegnato provvisoriamente nei ruoli unici istituiti presso la Presidenza del Consiglio dei ministri ai sensi del decreto del Presidente della Repubblica 24 luglio 1977, n. 618, con le procedure e i criteri di cui all'articolo 1-quaterdecies della legge 21 ottobre 1978, n. 641, nella posizione giuridica e di livello funzionale ricoperta all'atto dell'assegnazione. A tutto il personale assegnato in via transitoria ai ruoli unici ai sensi della presente legge e della legge 21 ottobre 1978, n. 641, continua ad applicarsi fino alla data dell'inquadramento definitivo nei ruoli unificati dei dipendenti civili dello Stato il trattamento economico, normativo e di fine servizio previsto dalle leggi e dagli ordinamenti degli enti o delle gestioni di provenienza. Il personale gia' comandato presso amministrazioni statali ai sensi dell'articolo 6 della legge 29 giugno 1977, n. 349, e' trasferito ai ruoli unici di cui al comma precedente ed e' assegnato, a domanda, all'amministrazione presso la quale presta servizio, unitamente a quello gia' assegnato ai sensi dell'articolo 6 della legge 23 dicembre 1975, n. 698. Fino a sei mesi dall'entrata in funzione delle unita' sanitarie locali e' consentita la possibilita' di convenzionare con le limitazioni previste dall'articolo 48, terzo comma, numero 4), i medici dipendenti degli enti di cui agli articoli 67, 68, 72, 75, gia' autorizzati in base alle vigenti disposizioni. (6) ((10))

--------------- AGGIORNAMENTO (6) Il D.L. 1 luglio 1980, n. 285, convertito, con modificazioni, dalla L. 8 agosto 1980, n. 441, ha disposto (con l'art. 5, comma 5) che: "Il termine di cui all'ultimo comma dell'articolo 67 della legge 23 dicembre 1978, n. 833, e' uniformemente stabilito in quello dell'entrata in vigore dell'accordo previsto dall'ottavo comma dell'articolo 47 della stessa legge, comunque non oltre il 1 luglio 1981". --------------- AGGIORNAMENTO (10) Il D.L. 1 luglio 1980, n. 285, convertito, con modificazioni, dalla L. 8 agosto 1980, n. 441, come modificato dal D.L. 26 novembre 1981, n. 678, ha disposto (con l'art. 5, comma 5) che: "Il termine di cui all'ultimo comma dell'articolo 67 della legge 23 dicembre 1978, n. 833, e' uniformemente stabilito in quello dell'entrata in vigore dell'accordo previsto dall'ottavo comma dell'articolo 47 della stessa legge".

### Art. 68. - (Norme per il trasferimento del personale di enti locali)

Con legge regionale entro il 30 giugno 1979 e' disciplinata l'iscrizione nei ruoli nominativi regionali di cui al quarto comma, numero 1), dell'articolo 47 del personale dipendente dagli enti di cui alle lettere a) e b) del primo comma dell'articolo 66 nonche' dai comuni che risulti addetto ai servizi sanitari trasferiti, in modo continuativo da data non successiva al 30 giugno 1977, salvo le assunzioni conseguenti a concorsi pubblici espletati fino alla entrata in vigore della presente legge. Con la medesima legge e con gli stessi criteri e modalita' di cui al primo comma, e parimenti iscritto nei ruoli regionali di cui al precedente comma, il personale tecnico-sanitario, trasferito e gia' inquadrato nei ruoli della regione, proveniente da posti di ruolo conseguiti per effetto di pubblico concorso, presso gli uffici sanitari comunali, i laboratori provinciali di igiene e profilassi delle due sezioni e altri servizi degli enti locali, che ne faccia richiesta, alla regione di appartenenza, entro 120 giorni dall'emanazione del decreto governativo di cui all'articolo 47 della presente legge. Parimenti il personale tecnico-sanitario assunto dalle regioni per i servizi regionali puo' essere inquadrato, se ne fa richiesta entro i termini anzidetti, nel servizio sanitario nazionale, con le disposizioni di cui allo stesso articolo 47, comma quinto, lettera c). Il personale di cui ai precedenti commi e' assegnato alle unita' sanitarie locali, nella posizione giuridica e funzionale corrispondente a quella ricoperta nell'ente di provenienza, secondo le tabelle di equiparazione previste dall'articolo 47, terzo comma, numero 3). Sino all'entrata in vigore del primo accordo nazionale unico di cui al nono comma dell'articolo 47 al personale in oggetto spetta il trattamento economico previsto dall'ordinamento vigente presso gli enti di provenienza, ivi compresi gli istituti economico-normativi previsti dalle leggi 18 marzo 1968, n. 431, e 21 giugno 1971, n. 515, e dai decreti applicativi delle medesime, nonche' dall'articolo 13 della legge 29 giugno 1977, n. 349.

### Art. 69. - (Entrate del fondo sanitario nazionale)

A decorrere dal 1 gennaio 1979, in relazione a quanto disposto negli articoli 51 e 52, sono versati all'entrata del bilancio dello Stato: a) i contributi assicurativi di cui all'articolo 76; b) le somme gia' destinate in via diretta e indiretta dalle regioni, dalle province, dai comuni e loro consorzi, nonche' da altri enti pubblici al finanziamento delle funzioni esercitate in materia sanitaria, in misura non inferiore a quelle accertate nell'anno 1977 maggiorate del 14 per cento; (11) (15) ((16)) c) i proventi ed i redditi netti derivanti dal patrimonio trasferito ai comuni per le unita' sanitarie locali; ((16)) d) gli avanzi annuali delle gestioni dell'assicurazione contro la tubercolosi gestite dall'INPS e da altri enti mutuo-previdenziali; ((16)) e) i proventi derivanti da attivita' a pagamento svolte dalle unita' sanitarie locali e dai presidi sanitari ad esse collegati, nonche' da recuperi, anche a titolo di rivalsa. Le somme di cui alla lettera b) possono essere trattenute, a compensazione, sui trasferimenti di fondi dello Stato a favore degli enti ivi indicati. Sono altresi' versate all'entrata del bilancio dello Stato i proventi ed i redditi netti derivanti, per l'anno 1979, dal patrimonio degli enti ospedalieri e degli enti, casse, servizi e gestioni autonome in liquidazione, di cui all'articolo 12-bis del decreto-legge 8 luglio 1974, n. 264, convertito nella legge 17 agosto 1974, n. 386. I versamenti al bilancio dello Stato devono essere effettuati: per i contributi assicurativi di cui alla lettera a) entro i termini previsti dall'articolo 24 della legge finanziaria per le somme di cui alla lettera b) entro 15 giorni dal termine di ogni trimestre nella misura di 3/12 dello stanziamento di bilancio; per i proventi ed i redditi di cui alle lettere c) ed e) nonche' di quelli di cui al terzo comma entro 15 giorni dalla fine di ogni trimestre; per gli avanzi di cui alla lettera d) entro 15 giorni dall'approvazione dei bilanci consuntivi della gestione. Alla riscossione delle somme dovute ai sensi del presente articolo e non versate allo Stato nei termini previsti, nonche' ai relativi interessi di mora, provvede l'Intendenza di finanza, secondo le disposizioni del testo unico 14 aprile 1910, n. 639, relativo alla procedura coattiva per la riscossione delle entrate patrimoniali dello Stato. Cessano di avere vigore, con effetto dal 1 gennaio 1979, le norme che prevedono la concessione di contributi dello Stato ad enti, organismi e gestioni il cui finanziamento e' previsto dalla presente legge. (15)

--------------- AGGIORNAMENTO (11) Il D.L. 25 gennaio 1982, n. 16, convertito, con modificazioni, dalla L. 25 marzo 1982, n. 98 (in G.U. 27/03/1982, n. 85) ha disposto (con l'art. 1, comma 6)che: "Per il 1982, il versamento al bilancio dello Stato previsto a carico dell'INPS e dell'INAIL dall'articolo 69, primo comma, lettera b), della legge 23 dicembre 1978, n. 833, e' elevato dal 16 per cento rispetto a quello previsto per il 1981 dal secondo comma dell'articolo 8-ter del decreto-legge 30 aprile 1981, n. 168, convertito nella legge 27 giugno 1981, n. 331". --------------- AGGIORNAMENTO (15) Il D.L. 12 settembre 1983, n. 463, convertito, con modificazioni, dalla L. 11 novembre 1983, n. 638 (in G.U. 11/11/1983, n. 310) ha disposto (con l'art. 13, comma 2) che: "Per l'anno 1983 il versamento al bilancio dello Stato previsto a carico dell'INPS e dell'INAIL dall'articolo 69, lettera b), della legge 23 dicembre 1978, n. 833, e' elevato del 13 per cento rispetto a quello previsto per 1982 dall'articolo 1 del decreto-legge 25 gennaio 1982, n. 16, convertito, con modificazioni, nella legge 25 marzo 1982, n. 98". Lo stesso D.L. (con l'art. 15, comma 5) ha, inoltre, disposto che: "In deroga all'articolo 69 della legge 23 dicembre 1978, n. 833, le regioni e le province autonome di Trento e Bolzano nonche' le unita' sanitarie locali sono autorizzate a trattenere le somme di cui alle lettere b), c) ed e) del medesimo articolo per gli anni 1983 e precedenti. Le predette somme sono utilizzate per le quote fino al 31 dicembre 1982 a copertura degli eventuali disavanzi d'esercizio sul fondo sanitario e per il 1983, nel limite della meta', ad integrazione dello stanziamento di competenza, per la provvista di apparecchiature ed attrezzature tecniche e scientifiche, nell'ambito del piano triennale di investimenti previsto dal bilancio pluriennale dello Stato. Restano acquisiti al bilancio dello Stato i versamenti effettuati precedentemente alla data di entrata in vigore del presente decreto". --------------- AGGIORNAMENTO (16) La L. 27 dicembre 1983, n. 730, ha disposto (con l'art. 25, comma 2) che: "A modifica di quanto previsto dall'articolo 69 della legge 23 dicembre 1978, n. 833, le somme di cui alle lettere b), c) ed e) del primo comma dello stesso articolo sono trattenute dalle unita' sanitarie locali, dalle regioni e province autonome e sono utilizzate per il 50 per cento ad integrazione del finanziamento di parte corrente e per il 50 per cento per l'acquisto di attrezzature in conto capitale".

### Art. 70. - (Scorporo dei servizi sanitari della Croce Rossa italiana - CRI - e riordinamento dell'Associazione)

Con effetto dal 1 gennaio 1980, con decreto del Ministro della sanita', sentito il Consiglio sanitario nazionale, sono trasferiti ai comuni competenti per territorio per essere destinati alle unita' sanitarie locali i servizi di assistenza sanitaria dell'Associazione della Croce rossa italiana (CRI), non connessi direttamente alle sue originarie finalita', nonche' i beni mobili ed immobili destinati ai predetti servizi ed il personale ad essi adibito, previa individuazione del relativo contingente. Per il trasferimento dei beni e del personale si adottano in quanto applicabili le disposizioni di cui agli articoli 65 e 67. Il Governo, entro un anno dall'entrata in vigore della presente legge, e' delegato ad emanare, su proposta del Ministro della sanita', di concerto con il Ministro della difesa, uno o piu' decreti aventi valore di legge ordinaria per il riordinamento della Associazione della Croce rossa italiana con l'osservanza dei seguenti criteri direttivi: 1) l'organizzazione dell'Associazione dovra' essere ristrutturata in conformita' del principio volontaristico della Associazione stessa; 2) i compiti dell'Associazione dovranno essere rideterminati in relazione alle finalita' statutarie ed agli adempimenti commessi dalle vigenti convenzioni e risoluzioni internazionali e dagli organi della Croce rossa internazionale alle societa' di Croce rossa nazionali; 3) le strutture dell'Associazione, pur conservando l'unitarieta' del sodalizio, dovranno essere articolate su base regionale; 4) le cariche dovranno essere gratuite e dovra' esserne prevista l'elettivita' da parte dei soci qualificati per attive prestazioni volontarie nell'ambito dell'Associazione. ((4))

--------------- AGGIORNAMENTO (4) La L. 29 febbraio 1980, n. 33, ha disposto (con l'art. 2, comma 1) che: "Le deleghe conferite al Governo con gli articoli 7, 42 e 70 della legge 23 dicembre 1978, n. 833, scadute il 23 dicembre 1979, nonche' le deleghe conferite con gli articoli 23 e 37 della legge medesima, scadute il 31 dicembre 1979, sono rinnovate fino al 31 luglio 1980".

### Art. 71. - (Compiti delle Associazioni di volontariato)

I compiti di cui all'articolo 2, lettera b), del decreto del Capo provvisorio dello Stato 13 novembre 1947, n. 1256, possono essere svolti anche dalle Associazioni di volontariato di cui al precedente articolo 45, in base a convenzioni da stipularsi con le unita' sanitarie locali interessate per quanto riguarda le competenze delle medesime.

### Art. 72. - (Soppressione dell'Ente nazionale per la prevenzione degli infortuni - ENFI - e dell'Associazione nazionale per il controllo della combustione - ANCC -)

Con decreto del Presidente della Repubblica, previa delibera del Consiglio dei ministri, su proposta dei Ministri del lavoro e della previdenza sociale, della sanita', dell'industria, il commercio e l'artigianato e del tesoro, da emanarsi entro sessanta giorni dall'entrata in vigore della presente legge, e' dichiarata l'estinzione dell'Ente nazionale per la prevenzione degli infortuni (ENPI) e dell'Associazione nazionale per il controllo della combustione (ANCC) e ne sono nominati i commissari liquidatori. Ai predetti commissari liquidatori sono attribuiti, sino al 31 dicembre 1979, i compiti e le funzioni che la legge 29 giugno 1977, n. 349, attribuisce ai commissari liquidatori degli enti mutualistici. La liquidazione dell'ENPI e dell'ANCC e' disciplinata ai sensi dell'articolo 77. A decorrere dal 1 gennaio 1980 i compiti e le funzioni svolti dall'ENPI e dalla ANCC sono attribuiti rispettivamente ai comuni, alle regioni e agli organi centrali dello Stato, con riferimento all'attribuzione di funzioni che nella stessa materia e' disposta dal decreto del Presidente della Repubblica 24 luglio 1977, n. 616, e dalla presente legge. Nella legge istitutiva dell'Istituto superiore per la prevenzione e per la sicurezza del lavoro sono individuate le attivita' e le funzioni gia' esercitate dall'ENPI e dall'ANCC attribuite al nuovo Istituto e al CNEN. A decorrere dalla data di cui al precedente comma, al personale, centrale e periferico, dell'ENPI e dell'ANCC, si applicano le procedure dell'articolo 67 al fine di individuare il personale da trasferire all'Istituto superiore per la sicurezza e la prevenzione del lavoro e da iscrivere nei ruoli regionali per essere destinato ai servizi delle unita' sanitarie locali e in particolare ai servizi di cui all'articolo 22. Si applicano per il trasferimento dei beni dell'ENPI e della ANCC le norme di cui all'articolo 65 ad eccezione delle strutture scientifiche e dei laboratori centrali da destinare all'Istituto superiore per la sicurezza e la prevenzione del lavoro. ((3))

--------------- AGGIORNAMENTO (3) Il D.L. 30 dicembre 1979, n. 663, convertito, con modificazioni dalla L. 29 febbraio 1980, n. 33, ha disposto (con l'art. 5, comma 7) che "Fino all'emanazione della disciplina legislativa prevista rispettivamente dagli articoli 23 e 37 della legge 23 dicembre 1978, n. 833, e del decreto di cui al primo comma dell'articolo 70 della stessa legge, sono prorogati tutti i poteri dei commissari liquidatori nominati ai Sensi dell'articolo 72 della citata legge 23 dicembre 1978, n. 833, dei commissari liquidatori delle gestioni e servizi di assistenza sanitaria delle Casse marittime adriatica, tirrena e meridionale, nonche', per la parte riguardante le suddette materie, dei commissari di cui al successivo comma e degli organi di amministrazione della Croce rossa italiana".

### Art. 73. - (Trasferimento di personale statale addetto alle attivita' di prevenzione e di sicurezza del lavoro)

In riferimento a quanto disposto dallo articolo 21, primo comma, con provvedimento del Ministro del lavoro e della previdenza sociale, il personale tecnico e sanitario centrale e periferico, degli Ispettorati del lavoro addetto alle sezioni mediche, chimiche e ai servizi di protezione antinfortunistica, viene comandato, a domanda e a decorrere dal 1 gennaio 1980, presso l'Istituto superiore per la prevenzione e la sicurezza del lavoro, o nei presidi e servizi delle unita' sanitarie locali e, in particolare, nei presidi di cui all'articolo 22. Per il provvedimento di cui al primo comma si adottano, in quanto applicabili, le procedure di cui all'articolo 67.

### Art. 74. - (Indennita' economiche temporanee)

A decorrere dal 1 gennaio 1980 e sino all'entrata in vigore della legge di riforma del sistema previdenziale, l'erogazione delle prestazioni economiche per malattia e per maternita' previste dalle vigenti disposizioni in materia gia' erogate dagli enti, casse, servizi e gestioni autonome estinti e posti in liquidazione ai sensi della legge 17 agosto 1974, n. 386, di conversione con modificazioni del decreto-legge 8 luglio 1974, n. 264, e' attribuita all'Istituto nazionale della previdenza sociale (INPS) che terra' apposita gestione. A partire dalla stessa data la quota parte dei contributi di legge relativi a tali prestazioni e' devoluta all'INPS ed e' stabilita con decreto del Ministro del lavoro e della previdenza sociale, di concerto col Ministro del tesoro. Resta ferma presso l'Istituto nazionale della previdenza sociale (INPS) la gestione dell'assicurazione contro la tubercolosi, con compiti limitati all'erogazione delle sole prestazioni economiche. Entro la data di cui al primo comma con legge dello Stato si provvede a riordinare la intera materia delle prestazioni economiche per maternita', malattia ed infortunio. ((8))

--------------- AGGIORNAMENTO (8) La L. 23 aprile 1981, n. 155, ha disposto (con l'art. 14, comma 1) che: "La quota parte dei contributi da devolvere all'Istituto nazionale della previdenza sociale ai sensi dell'articolo 74 della legge 23 dicembre 1978, n. 833, per la erogazione delle prestazioni economiche di malattia e' determinata nella misura del 2,50 per cento della retribuzione imponibile per gli aventi diritto di tutti i settori, ad esclusione di quello agricolo, per il quale il contributo stesso e' determinato nella misura di un sesto del contributo giornaliero di malattia. Per gli aventi diritto alle prestazioni economiche previste dalle disciolte Casse di soccorso la quota di contributo e' fissata nella misura del 3 per cento".

### Art. 75. - (Rapporto con gli enti previdenziali)

Entro il 31 dicembre 1980, con legge dello Stato sono disciplinati gli aspetti previdenziali connessi con le competenze in materia di medicina legale attribuite alle unita' sanitarie locali ai sensi dell'articolo 14, lettera q). Sino all'entrata in vigore della legge di cui al precedente comma gli enti previdenziali gestori delle assicurazioni invalidita', vecchiaia, superstiti, tubercolosi, assegni familiari, infortuni sul lavoro e malattie professionali conservano le funzioni concernenti le attivita' medico-legali ed i relativi accertamenti e certificazioni, nonche' i beni, le attrezzature ed il personale strettamente necessari all'espletamento delle funzioni stesse, salvo quanto disposto dal comma successivo. Fermo restando il termine sopra previsto gli enti previdenziali di cui al precedente comma stipulano convenzioni con le unita' sanitarie locali per utilizzare i servizi delle stesse, ivi compresi quelli medico-legali, per la istruttoria delle pratiche previdenziali. Le gestioni commissariali istituite ai sensi dell'articolo 12-bis del decreto-legge 8 luglio 1974, n. 264, come modificato dalla legge di conversione 17 agosto 1974, n. 386, in relazione ai compiti di assistenza sanitaria degli enti previdenziali di cui al secondo comma cessano secondo le modalita' e nei termini di cui all'articolo 61. Gli enti previdenziali di cui al presente articolo, fino alla data indicata nel primo comma, applicano al personale medico dipendente dagli stessi gli istituti normativi previsti specificamente per i medici dalle norme delegate di cui all'articolo 47.

### Art. 76. - (Modalita' transitorie per la riscossione dei contributi obbligatori di malattia)

Fino al 31 dicembre 1979 gli adempimenti relativi all'accertamento, alla riscossione e al recupero in via giudiziale dei contributi sociali di malattia e di ogni altra somma ad essi connessa restano affidati agli enti mutualistici ed altri istituti e gestioni interessati, posti in liquidazione ai sensi della legge 29 giugno 1977, n. 349. A decorrere dal 1 gennaio 1980 e fino alla completa fiscalizzazione degli oneri sociali tali adempimenti sono affidati all'INPS, che terra' contabilita' separate per ciascuno degli enti o gestioni soppressi e vi provvedera' secondo le norme e le procedure in vigore per l'accertamento e la riscossione dei contributi di propria pertinenza. ((COMMA ABROGATO DAL D.L. 30 DICEMBRE 1979, N. 663, CONVERTITO, CON MODIFICAZIONI DALLA L. 29 FEBBRAIO 1980, N. 33)) I contributi di competenza degli enti di malattia dovranno affluire in apposito conto corrente infruttifero di tesoreria intestato al Ministro del tesoro, mediante versamento da parte dei datori di lavoro o degli esattori od enti, incaricati della riscossione a mezzo ruolo, con bollettino di conto corrente postale o altro idoneo sistema stabilito con decreto del Ministro del lavoro e della previdenza sociale, di concerto con il Ministro del tesoro. ((3)) Restano salve le sanzioni penali previste in materia dalla vigente legislazione. Per l'attuazione dei nuovi compiti provvisoriamente attribuiti ai sensi del presente articolo, l'INPS, sia a livello centrale che periferico, e' tenuto ad avvalersi di personale degli enti gia' preposti a tali compiti. Le competenze fisse ed accessorie ed i relativi oneri riflessi sono a carico dell'INPS. A decorrere dal 1 gennaio 1980 vengono affidati all'INPS gli adempimenti previsti da convenzioni gia' stipulate con l'INAM ai sensi della legge 4 giugno 1973, n. 311, dalle organizzazioni sindacali maggiormente rappresentative a carattere nazionale.

--------------- AGGIORNAMENTO (3) Il D.L. 30 dicembre 1979, n. 663, convertito, con modificazioni, dalla L. 29 febbraio 1980, n. 33 (in G.U. 29/02/1980, n. 59) ha disposto (con l'art. 3, comma 5) che: "A decorrere dal 1 gennaio 1980, in deroga a quanto previsto dal quarto comma all'articolo 76 della legge 23 dicembre 1978 n. 833 i contributi di competenza degli enti di malattia sono riscossi dall'INPS che versera', entro la fine di ciascun mese, a partire da quello di febbraio 1980, nell'apposito capitolo dello stato di previsione dell'entrata del bilancio dello Stato un acconto pari a un dodicesimo dell'80 per cento dei contributi di competenza per l'assistenza sanitaria iscritti nell'anzidetto capitolo al netto di eventuali quota fiscalizzate e dei contributi dovuti dalle amministrazioni statali ivi comprese quelle con ordinamento autonomo o dotate di autonomia amministrativa che provvederanno direttamente al versamento degli stessi a bilancio dello Stato. I relativi conguagli saranno effettuati con le modalita' e le scadenze da stabilirsi con decreto del Ministro del tesoro, di concerto con quello del lavoro e della previdenza sociale".

### Art. 77. - (Liquidazione degli enti soppressi e ripiano delle loro passivita')

Fermo restando quanto disposto dal secondo comma dell'articolo 60, alla liquidazione degli enti, casse, servizi e gestioni autonome di cui all'articolo 12-bis del decreto-legge 8 luglio 1974, n. 264, come modificato dalla legge di conversione 17 agosto 1974, n. 386, si provvede, entro 18 mesi dall'entrata in vigore della presente legge, sulla base delle direttive emanate, in applicazione dell'articolo 4, quarto comma, della legge 29 giugno 1977, n. 349, dal comitato centrale istituito con lo stesso articolo 4. ((6)) Prima che siano esaurite le operazioni di liquidazione degli enti, casse, servizi e gestioni autonome di cui al precedente comma, i commissari liquidatori provvedono a definire tutti i provvedimenti da adottarsi in esecuzione di decisioni degli organi di giustizia amministrativa non piu' suscettibili di impugnativa. Entro lo stesso periodo i commissari liquidatori provvedono, ai soli fini giuridici, alla ricostruzione della carriera dei dipendenti che, trovandosi in aspettativa per qualsiasi causa, ne abbiano diritto al termine della aspettativa in base a norme di legge o regolamentari. Le gestioni di liquidazione che non risultano chiuse nel termine di cui al primo comma sono assunte dallo speciale ufficio liquidazioni presso il Ministero del tesoro di cui alla legge 4 dicembre 1956, n. 1404. I commissari liquidatori delle gestioni di cui al terzo comma cessano dalle loro funzioni il trentesimo giorno successivo alla data di assunzione delle gestioni stesse da parte dell'ufficio liquidazioni. Entro tale termine essi devono consegnare all'ufficio liquidazioni medesimo tutte le attivita' esistenti, i libri contabili, gli inventari ed il rendiconto della loro intera gestione. Le disponibilita' finanziarie delle gestioni di cui al terzo comma sono fatte affluire in apposito conto corrente infruttifero di tesoreria dal quale il Ministro del tesoro puo' disporre prelevamenti per la sistemazione delle singole liquidazioni e per la copertura dei disavanzi di quelle deficitarie. Eventuali disavanzi di liquidazione, che non e' possibile coprire a carico del conto corrente di cui al quinto comma, saranno finanziati a carico del fondo previsto dall'articolo 14 della legge 4 dicembre 1956, n. 1404, per la cui integrazione il Ministro del tesoro e autorizzato ad effettuare operazioni di ricorso al mercato finanziario con l'osservanza delle norme di cui all'articolo 1 del decreto-legge 8 luglio 1974, n. 264, convertito, con modificazioni, nella legge 17 agosto 1974, n. 386. Agli oneri derivanti dalle predette operazioni finanziarie si provvede per il primo anno con una corrispondente maggiorazione delle operazioni stesse e per gli anni successivi con appositi stanziamenti da iscrivere annualmente nello stato di previsione della spesa del Ministero del tesoro. Per le esigenze della gestione di liquidazione di cui al terzo comma si applica il disposto dell'articolo 12, quarto comma, della legge 4 dicembre 1956, n. 1404.

--------------- AGGIORNAMENTO (6) Il D.L. 1 luglio 1980, n. 285, convertito, con modificazioni, dalla L. 8 agosto 1980, n. 441, ha disposto (con l'art. 1, comma 5) che "La data prevista nel primo comma dell'art. 77 della legge 23 dicembre 1978, n. 833, per la cessazione delle gestioni di liquidazione degli enti di cui al precedente primo comma e' prorogata al 31 dicembre 1980".

### Art. 78. - (Norme fiscali)

I trasferimenti di beni mobili ed immobili dipendenti dall'attuazione della presente legge, sono esenti, senza limiti di valore, dalle imposte di bollo, di registro, di incremento di valore, ipotecarie, catastali e da ogni altra imposta, spesa, tassa o diritto di qualsiasi specie o natura.

### Art. 79. - (Esercizio delle deleghe legislative)

Le norme delegate previste dalla presente legge sono emanate, con decreti del Presidente della Repubblica, su proposta del Presidente del Consiglio dei ministri, di concerto con i Ministri del tesoro, dell'interno e del bilancio e della programmazione economica e degli altri Ministri, in ragione delle rispettive competenze indicate nei precedenti articoli, adottando la procedura complessivamente prevista dall'articolo 8 della legge 22 luglio 1975, n. 382. Per l'esercizio delle deleghe di cui agli articoli 23, 24, 37, 42, 47 e 59 in luogo della Commissione parlamentare per le questioni regionali, di cui all'articolo 52 della legge 10 febbraio 1953, n. 62 e successive modificazioni e integrazioni, i pareri sono espressi da una apposita Commissione composta da 10 deputati e 10 senatori nominati, in rappresentanza proporzionale dei gruppi parlamentari, dai Presidenti delle rispettive Camere.

### Art. 80. - (Regioni a statuto speciale)

Restano salve le competenze statutarie delle regioni a statuto speciale nelle materie disciplinate dalla presente legge. Restano ferme altresi' le competenze spettanti alle province autonome di Trento e di Bolzano secondo le forme e condizioni particolari di autonomia definite dal decreto del Presidente della Repubblica 31 agosto 1972, n. 670, e relative norme di attuazione, nel rispetto, per quanto attiene alla provincia autonoma di Bolzano, anche delle norme relative alla ripartizione proporzionale fra i gruppi linguistici e alla parificazione delle lingue italiana e tedesca. ((PERIODO ABROGATO DALLA L. 27 DICEMBRE 1983, N. 730)). Al trasferimento delle funzioni, degli uffici, del personale e dei beni alle regioni Valle d'Aosta, Friuli-Venezia Giulia, Sardegna, Sicilia, nonche' alle province autonome di Trento e di Bolzano, si provvedera' con le procedure previste dai rispettivi statuti. (13) Appositi accordi o convenzioni regolano i rapporti tra la Regione Valle d'Aosta e l'Ordine Mauriziano per quanto riguarda la utilizzazione dello Stabilimento di ricovero e cura di Aosta.

--------------- AGGIORNAMENTO (13) Il D.P.R. 22 febbraio 1982, n. 182, ha disposto (con l'art. 22, comma 2) che: "A parziale modifica di quanto disposto dall'art. 80, secondo comma, della legge 23 dicembre 1978, n. 833, il trasferimento delle funzioni di cui al comma precedente, degli uffici, del personale e dei beni alla regione ha luogo con le procedure previste dalla legge stessa per le regioni a statuto ordinario".

### Art. 81. - (Assistenza ai mutilati e agli invalidi civili)

Il trasferimento delle funzioni amministrative in materia di assistenza sanitaria protesica e specifica a favore dei mutilati e invalidi di cui all'articolo 2 della legge 30 marzo 1971, n. 118, nonche' dei sordomuti e ciechi civili diventa operativo a partire dal 1 luglio 1979.

### Art. 82. - (Variazioni al bilancio dello Stato)

Il Ministro del tesoro e' autorizzato a provvedere con propri decreti alle occorrenti variazioni di bilancio.

### Art. 83. - (Entrata in vigore della legge)

La presente legge entra in vigore il giorno della sua pubblicazione nella Gazzetta Ufficiale della Repubblica. Le disposizioni di cui ai Capi II, III e V del Titolo I e quelle di cui al Titolo III avranno effetto dal 1 gennaio 1979.

